@@ -9,9 +9,20 @@ or GPL2.txt for full copies of the license.
 #ifndef __FILLERS_H
 #define __FILLERS_H
 
+/*
+ * https://chromium.googlesource.com/chromiumos/third_party/kernel/+/096925a44076ba5c52faa84d255a847130ff341e%5E%21/#F2
+ * This commit diverged the ChromiumOS kernel from stock in the area of audit
+ * information, which this probe accesses.
+ *
+ * If running on a patched version of COS, enable this #define to get the
+ * probe to build.
+ */
+//#define COS_73_WORKAROUND
+
 #include "../ppm_flag_helpers.h"
 
 #include <linux/tty.h>
+#include <linux/audit.h>
 
 #define FILLER_RAW(x)							\
 static __always_inline int __bpf_##x(struct filler_data *data);		\
@@ -123,6 +134,8 @@ FILLER(sys_open_x, true)
 	unsigned int flags;
 	unsigned int mode;
 	unsigned long val;
+	unsigned long dev;
+	unsigned long ino;
 	long retval;
 	int res;
 
@@ -157,7 +170,16 @@ FILLER(sys_open_x, true)
 	mode = bpf_syscall_get_argument(data, 2);
 	mode = open_modes_to_scap(val, mode);
 	res = bpf_val_to_ring(data, mode);
+	if (res != PPM_SUCCESS)
+		return res;
 
+	/*
+	 * Device
+	 */
+	if (retval < 0 || !bpf_get_fd_dev_ino(retval, &dev, &ino))
+		dev = 0;
+
+	res = bpf_val_to_ring(data, dev);
 	return res;
 }
 
@@ -332,7 +354,7 @@ FILLER(sys_poll_x, true)
 	return res;
 }
 
-#define MAX_IOVCNT 8
+#define MAX_IOVCNT 32
 
 static __always_inline int bpf_parse_readv_writev_bufs(struct filler_data *data,
 						       const struct iovec __user *iovsrc,
@@ -899,6 +921,265 @@ FILLER(sys_socketpair_x, true)
 	return res;
 }
 
+static int __always_inline parse_sockopt(struct filler_data *data, int level, int optname, void *optval, int optlen)
+{
+	union {
+		uint32_t val32;
+		uint64_t val64;
+		struct timeval tv;
+	} u;
+
+	if (level == SOL_SOCKET) {
+		switch (optname) {
+#ifdef SO_ERROR
+			case SO_ERROR:
+				if (bpf_probe_read(&u.val32, sizeof(u.val32), optval))
+					return PPM_FAILURE_INVALID_USER_MEMORY;
+				return bpf_val_to_ring_dyn(data, -u.val32, PT_ERRNO, PPM_SOCKOPT_IDX_ERRNO);
+#endif
+
+#ifdef SO_RCVTIMEO
+			case SO_RCVTIMEO:
+#endif
+#ifdef SO_SNDTIMEO
+			case SO_SNDTIMEO:
+#endif
+				if (bpf_probe_read(&u.tv, sizeof(u.tv), optval))
+					return PPM_FAILURE_INVALID_USER_MEMORY;
+				return bpf_val_to_ring_dyn(data, u.tv.tv_sec * 1000000000 + u.tv.tv_usec * 1000, PT_RELTIME, PPM_SOCKOPT_IDX_TIMEVAL);
+
+#ifdef SO_COOKIE
+			case SO_COOKIE:
+				if (bpf_probe_read(&u.val64, sizeof(u.val64), optval))
+					return PPM_FAILURE_INVALID_USER_MEMORY;
+				return bpf_val_to_ring_dyn(data, u.val64, PT_UINT64, PPM_SOCKOPT_IDX_UINT64);
+#endif
+
+#ifdef SO_DEBUG
+			case SO_DEBUG:
+#endif
+#ifdef SO_REUSEADDR
+			case SO_REUSEADDR:
+#endif
+#ifdef SO_TYPE
+			case SO_TYPE:
+#endif
+#ifdef SO_DONTROUTE
+			case SO_DONTROUTE:
+#endif
+#ifdef SO_BROADCAST
+			case SO_BROADCAST:
+#endif
+#ifdef SO_SNDBUF
+			case SO_SNDBUF:
+#endif
+#ifdef SO_RCVBUF
+			case SO_RCVBUF:
+#endif
+#ifdef SO_SNDBUFFORCE
+			case SO_SNDBUFFORCE:
+#endif
+#ifdef SO_RCVBUFFORCE
+			case SO_RCVBUFFORCE:
+#endif
+#ifdef SO_KEEPALIVE
+			case SO_KEEPALIVE:
+#endif
+#ifdef SO_OOBINLINE
+			case SO_OOBINLINE:
+#endif
+#ifdef SO_NO_CHECK
+			case SO_NO_CHECK:
+#endif
+#ifdef SO_PRIORITY
+			case SO_PRIORITY:
+#endif
+#ifdef SO_BSDCOMPAT
+			case SO_BSDCOMPAT:
+#endif
+#ifdef SO_REUSEPORT
+			case SO_REUSEPORT:
+#endif
+#ifdef SO_PASSCRED
+			case SO_PASSCRED:
+#endif
+#ifdef SO_RCVLOWAT
+			case SO_RCVLOWAT:
+#endif
+#ifdef SO_SNDLOWAT
+			case SO_SNDLOWAT:
+#endif
+#ifdef SO_SECURITY_AUTHENTICATION
+			case SO_SECURITY_AUTHENTICATION:
+#endif
+#ifdef SO_SECURITY_ENCRYPTION_TRANSPORT
+			case SO_SECURITY_ENCRYPTION_TRANSPORT:
+#endif
+#ifdef SO_SECURITY_ENCRYPTION_NETWORK
+			case SO_SECURITY_ENCRYPTION_NETWORK:
+#endif
+#ifdef SO_BINDTODEVICE
+			case SO_BINDTODEVICE:
+#endif
+#ifdef SO_DETACH_FILTER
+			case SO_DETACH_FILTER:
+#endif
+#ifdef SO_TIMESTAMP
+			case SO_TIMESTAMP:
+#endif
+#ifdef SO_ACCEPTCONN
+			case SO_ACCEPTCONN:
+#endif
+#ifdef SO_PEERSEC
+			case SO_PEERSEC:
+#endif
+#ifdef SO_PASSSEC
+			case SO_PASSSEC:
+#endif
+#ifdef SO_TIMESTAMPNS
+			case SO_TIMESTAMPNS:
+#endif
+#ifdef SO_MARK
+			case SO_MARK:
+#endif
+#ifdef SO_TIMESTAMPING
+			case SO_TIMESTAMPING:
+#endif
+#ifdef SO_PROTOCOL
+			case SO_PROTOCOL:
+#endif
+#ifdef SO_DOMAIN
+			case SO_DOMAIN:
+#endif
+#ifdef SO_RXQ_OVFL
+			case SO_RXQ_OVFL:
+#endif
+#ifdef SO_WIFI_STATUS
+			case SO_WIFI_STATUS:
+#endif
+#ifdef SO_PEEK_OFF
+			case SO_PEEK_OFF:
+#endif
+#ifdef SO_NOFCS
+			case SO_NOFCS:
+#endif
+#ifdef SO_LOCK_FILTER
+			case SO_LOCK_FILTER:
+#endif
+#ifdef SO_SELECT_ERR_QUEUE
+			case SO_SELECT_ERR_QUEUE:
+#endif
+#ifdef SO_BUSY_POLL
+			case SO_BUSY_POLL:
+#endif
+#ifdef SO_MAX_PACING_RATE
+			case SO_MAX_PACING_RATE:
+#endif
+#ifdef SO_BPF_EXTENSIONS
+			case SO_BPF_EXTENSIONS:
+#endif
+#ifdef SO_INCOMING_CPU
+			case SO_INCOMING_CPU:
+#endif
+				if (bpf_probe_read(&u.val32, sizeof(u.val32), optval))
+					return PPM_FAILURE_INVALID_USER_MEMORY;
+				return bpf_val_to_ring_dyn(data, u.val32, PT_UINT32, PPM_SOCKOPT_IDX_UINT32);
+
+			default:
+				return __bpf_val_to_ring(data, (unsigned long)optval, optlen, PT_BYTEBUF, PPM_SOCKOPT_IDX_UNKNOWN, false);
+		}
+	} else {
+		return __bpf_val_to_ring(data, (unsigned long)optval, optlen, PT_BYTEBUF, PPM_SOCKOPT_IDX_UNKNOWN, false);
+	}
+}
+
+FILLER(sys_setsockopt_x, true)
+{
+	int res;
+	unsigned long retval, fd, level, optname, optval, optlen;
+
+	retval = bpf_syscall_get_retval(data->ctx);
+
+	/* retval */
+	res = bpf_val_to_ring_type(data, retval, PT_ERRNO);
+	if (res != PPM_SUCCESS)
+		return res;
+
+	/* fd */
+	fd = bpf_syscall_get_argument(data, 0);
+	res = bpf_val_to_ring_type(data, fd, PT_FD);
+	if (res != PPM_SUCCESS)
+		return res;
+
+	/* level */
+	level = bpf_syscall_get_argument(data, 1);
+	res = bpf_val_to_ring_type(data, sockopt_level_to_scap(level), PT_FLAGS8);
+	if (res != PPM_SUCCESS)
+		return res;
+
+	/* optname */
+	optname = bpf_syscall_get_argument(data, 2);
+	res = bpf_val_to_ring_type(data, sockopt_optname_to_scap(level, optname), PT_FLAGS8);
+	if (res != PPM_SUCCESS)
+		return res;
+
+	/* optval */
+	optval = bpf_syscall_get_argument(data, 3);
+	optlen = bpf_syscall_get_argument(data, 4);
+	res = parse_sockopt(data, level, optname, (void*)optval, optlen);
+	if (res != PPM_SUCCESS)
+		return res;
+
+	/* optlen */
+	res = bpf_val_to_ring_type(data, optlen, PT_UINT32);
+	return res;
+}
+
+FILLER(sys_getsockopt_x, true)
+{
+	int res;
+	unsigned long retval, fd, level, optname, optval, optlen_p, optlen;
+
+	retval = bpf_syscall_get_retval(data->ctx);
+
+	/* retval */
+	res = bpf_val_to_ring_type(data, retval, PT_ERRNO);
+	if (res != PPM_SUCCESS)
+		return res;
+
+	/* fd */
+	fd = bpf_syscall_get_argument(data, 0);
+	res = bpf_val_to_ring_type(data, fd, PT_FD);
+	if (res != PPM_SUCCESS)
+		return res;
+
+	/* level */
+	level = bpf_syscall_get_argument(data, 1);
+	res = bpf_val_to_ring_type(data, sockopt_level_to_scap(level), PT_FLAGS8);
+	if (res != PPM_SUCCESS)
+		return res;
+
+	/* optname */
+	optname = bpf_syscall_get_argument(data, 2);
+	res = bpf_val_to_ring_type(data, sockopt_optname_to_scap(level, optname), PT_FLAGS8);
+	if (res != PPM_SUCCESS)
+		return res;
+
+	/* optval */
+	optval = bpf_syscall_get_argument(data, 3);
+	optlen_p = bpf_syscall_get_argument(data, 4);
+	if (bpf_probe_read(&optlen, sizeof(optlen), (void*)optlen_p))
+		return PPM_FAILURE_INVALID_USER_MEMORY;
+
+	res = parse_sockopt(data, level, optname, (void*)optval, optlen);
+	if (res != PPM_SUCCESS)
+		return res;
+
+	/* optlen */
+	res = bpf_val_to_ring_type(data, optlen, PT_UINT32);
+	return res;
+}
+
 static __always_inline int f_sys_send_e_common(struct filler_data *data, int fd)
 {
 	unsigned long val;
@@ -1615,6 +1896,8 @@ FILLER(proc_startupdate_3, true)
 		kgid_t egid;
 		pid_t vtid;
 		pid_t vpid;
+		struct pid_namespace *pidns = bpf_task_active_pid_ns(task);
+		int pidns_level = _READ(pidns->level);
 
 		/*
 		 * flags
@@ -1626,6 +1909,18 @@ FILLER(proc_startupdate_3, true)
 
 		flags = clone_flags_to_scap(flags);
 
+		if(pidns_level != 0) {
+			flags |= PPM_CL_CHILD_IN_PIDNS;
+		} else {
+			struct nsproxy *nsproxy = _READ(task->nsproxy);
+			if(nsproxy) {
+				struct pid_namespace *pid_ns_for_children = _READ(nsproxy->pid_ns_for_children);
+				if(pid_ns_for_children != pidns) {
+					flags |= PPM_CL_CHILD_IN_PIDNS;
+				}
+			}
+		}
+
 		res = bpf_val_to_ring_type(data, flags, PT_FLAGS32);
 		if (res != PPM_SUCCESS)
 			return res;
@@ -1744,7 +2039,19 @@ FILLER(proc_startupdate_3, true)
 		 * loginuid
 		 */
 		/* TODO: implement user namespace support */
+#ifdef COS_73_WORKAROUND
+		{
+			struct audit_task_info* audit = _READ(task->audit);
+			if (audit) {
+				loginuid = _READ(audit->loginuid);
+			} else {
+				loginuid = INVALID_UID;
+			}
+		}
+#else
 		loginuid = _READ(task->loginuid);
+#endif
+
 		res = bpf_val_to_ring_type(data, loginuid.val, PT_INT32);
 		if (res != PPM_SUCCESS)
 			return res;
@@ -1895,6 +2202,8 @@ FILLER(sys_generic, true)
 
 FILLER(sys_openat_x, true)
 {
+	unsigned long dev;
+	unsigned long ino;
 	unsigned long flags;
 	unsigned long val;
 	unsigned long mode;
@@ -1941,7 +2250,16 @@ FILLER(sys_openat_x, true)
 	mode = bpf_syscall_get_argument(data, 3);
 	mode = open_modes_to_scap(val, mode);
 	res = bpf_val_to_ring(data, mode);
+	if (res != PPM_SUCCESS)
+		return res;
 
+	/*
+	 * Device
+	 */
+	if (retval < 0 || !bpf_get_fd_dev_ino(retval, &dev, &ino))
+		dev = 0;
+
+	res = bpf_val_to_ring(data, dev);
 	return res;
 }
 
@@ -2580,9 +2898,51 @@ FILLER(sys_sendmsg_x, true)
 	return res;
 }
 
+FILLER(sys_creat_x, true)
+{
+	unsigned long dev;
+	unsigned long ino;
+	unsigned long val;
+	unsigned long mode;
+	long retval;
+	int res;
+
+	retval = bpf_syscall_get_retval(data->ctx);
+	res = bpf_val_to_ring(data, retval);
+	if (res != PPM_SUCCESS)
+		return res;
+
+	/*
+	 * name
+	 */
+	val = bpf_syscall_get_argument(data, 0);
+	res = bpf_val_to_ring(data, val);
+	if (res != PPM_SUCCESS)
+		return res;
+
+	/*
+	 * mode
+	 */
+	mode = bpf_syscall_get_argument(data, 1);
+	mode = open_modes_to_scap(O_CREAT, mode);
+	res = bpf_val_to_ring(data, mode);
+	if (res != PPM_SUCCESS)
+		return res;
+
+	/*
+	 * Device
+	 */
+	if (retval < 0 || !bpf_get_fd_dev_ino(retval, &dev, &ino))
+		dev = 0;
+
+	res = bpf_val_to_ring(data, dev);
+	return res;
+}
+
 FILLER(sys_pipe_x, true)
 {
 	unsigned long ino;
+	unsigned long dev;
 	unsigned long val;
 	long retval;
 	int fds[2];
@@ -2611,7 +2971,7 @@ FILLER(sys_pipe_x, true)
 	if (res != PPM_SUCCESS)
 		return res;
 
-	if (!bpf_get_ino_fd(fds[0], &ino))
+	if (!bpf_get_fd_dev_ino(fds[0], &dev, &ino))
 		ino = 0;
 
 	res = bpf_val_to_ring(data, ino);
@@ -3615,8 +3975,8 @@ FILLER(sys_ptrace_x, true)
 			return res;
 
 		res = bpf_val_to_ring_dyn(data, 0, PT_UINT64, 0);
-		if (res != PPM_SUCCESS)
-			return res;
+
+		return res;
 	}
 
 	val = bpf_syscall_get_argument(data, 0);
@@ -3818,4 +4178,101 @@ FILLER(sys_autofill, true)
 	return res;
 }
 
+FILLER(sys_fchmodat_x, true)
+{
+	unsigned long val;
+	int res;
+	long retval;
+	unsigned int mode;
+
+	retval = bpf_syscall_get_retval(data->ctx);
+	res = bpf_val_to_ring(data, retval);
+	if (res != PPM_SUCCESS)
+		return res;
+
+	/*
+	 * dirfd
+	 */
+	val = bpf_syscall_get_argument(data, 0);
+	if ((int)val == AT_FDCWD)
+		val = PPM_AT_FDCWD;
+
+	res = bpf_val_to_ring(data, val);
+	if (res != PPM_SUCCESS)
+		return res;
+
+	/*
+	 * filename
+	 */
+	val = bpf_syscall_get_argument(data, 1);
+	res = bpf_val_to_ring(data, val);
+	if (res != PPM_SUCCESS)
+		return res;
+
+	/*
+	 * mode
+	 */
+	mode = bpf_syscall_get_argument(data, 2);
+	mode = chmod_mode_to_scap(mode);
+	res = bpf_val_to_ring(data, mode);
+
+	return res;
+}
+
+FILLER(sys_chmod_x, true)
+{
+	unsigned long val;
+	int res;
+	long retval;
+
+	retval = bpf_syscall_get_retval(data->ctx);
+	res = bpf_val_to_ring(data, retval);
+	if (res != PPM_SUCCESS)
+		return res;
+
+	/*
+	 * filename
+	 */
+	val = bpf_syscall_get_argument(data, 0);
+	res = bpf_val_to_ring(data, val);
+	if (res != PPM_SUCCESS)
+		return res;
+
+	/*
+	 * mode
+	 */
+	val = bpf_syscall_get_argument(data, 1);
+	res = bpf_val_to_ring(data, val);
+
+	return res;
+}
+
+FILLER(sys_fchmod_x, true)
+{
+	unsigned long val;
+	int res;
+	long retval;
+
+	retval = bpf_syscall_get_retval(data->ctx);
+	res = bpf_val_to_ring(data, retval);
+	if (res != PPM_SUCCESS)
+		return res;
+
+	/*
+	 * fd
+	 */
+	val = bpf_syscall_get_argument(data, 0);
+	res = bpf_val_to_ring(data, val);
+	if (res != PPM_SUCCESS)
+		return res;
+
+	/*
+	 * mode
+	 */
+	val = bpf_syscall_get_argument(data, 1);
+	res = bpf_val_to_ring(data, val);
+
+	return res;
+}
+
 #endif
