@@ -216,6 +216,15 @@ do {								\
 		pr_info(fmt, ##__VA_ARGS__);			\
 } while (0)
 
+inline void ppm_syscall_get_arguments(struct task_struct *task, struct pt_regs *regs, unsigned long *args)
+{
+#if (LINUX_VERSION_CODE < KERNEL_VERSION(5, 1, 0))
+    syscall_get_arguments(task, regs, 0, 6, args);
+#else
+    syscall_get_arguments(task, regs, args);
+#endif
+}
+
 /* compat tracepoint functions */
 static int compat_register_trace(void *func, const char *probename, struct tracepoint *tp)
 {
@@ -428,6 +437,9 @@ static int ppm_open(struct inode *inode, struct file *filp)
 	consumer->do_dynamic_snaplen = false;
 	consumer->need_to_insert_drop_e = 0;
 	consumer->need_to_insert_drop_x = 0;
+	consumer->fullcapture_port_range_start = 0;
+	consumer->fullcapture_port_range_end = 0;
+	consumer->statsd_port = PPM_PORT_STATSD;
 	bitmap_fill(g_events_mask, PPM_EVENT_MAX); /* Enable all syscall to be passed to userspace */
 	reset_ring_buffer(ring);
 	ring->open = true;
@@ -883,6 +895,31 @@ cleanup_ioctl_procinfo:
 		ret = 0;
 		goto cleanup_ioctl;
 	}
+	case PPM_IOCTL_SET_FULLCAPTURE_PORT_RANGE:
+	{
+		u32 encoded_port_range;
+
+		vpr_info("PPM_IOCTL_SET_FULLCAPTURE_PORT_RANGE, consumer %p\n", consumer_id);
+		encoded_port_range = (u32)arg;
+
+		consumer->fullcapture_port_range_start = encoded_port_range & 0xFFFF;
+		consumer->fullcapture_port_range_end = encoded_port_range >> 16;
+
+		pr_info("new fullcapture_port_range_start: %d\n", (int)consumer->fullcapture_port_range_start);
+		pr_info("new fullcapture_port_range_end: %d\n", (int)consumer->fullcapture_port_range_end);
+
+		ret = 0;
+		goto cleanup_ioctl;
+	}
+	case PPM_IOCTL_SET_STATSD_PORT:
+	{
+		consumer->statsd_port = (u16)arg;
+
+		pr_info("new statsd_port: %d\n", (int)consumer->statsd_port);
+
+		ret = 0;
+		goto cleanup_ioctl;
+	}
 	case PPM_IOCTL_MASK_ZERO_EVENTS:
 	{
 		vpr_info("PPM_IOCTL_MASK_ZERO_EVENTS, consumer %p\n", consumer_id);
@@ -1266,11 +1303,10 @@ static const unsigned char compat_nas[21] = {
 #ifdef _HAS_SOCKETCALL
 static enum ppm_event_type parse_socketcall(struct event_filler_arguments *filler_args, struct pt_regs *regs)
 {
-	unsigned long __user args[2];
+	unsigned long __user args[6] = {};
 	unsigned long __user *scargs;
 	int socketcall_id;
-
-	syscall_get_arguments(current, regs, 0, 2, args);
+	ppm_syscall_get_arguments(current, regs, args);
 	socketcall_id = args[0];
 	scargs = (unsigned long __user *)args[1];
 
@@ -1385,6 +1421,7 @@ static inline void record_drop_x(struct ppm_consumer_t *consumer, struct timespe
 static inline int drop_nostate_event(enum ppm_event_type event_type,
 				     struct pt_regs *regs)
 {
+	unsigned long args[6] = {};
 	unsigned long arg = 0;
 	int close_fd = -1;
 	struct files_struct *files;
@@ -1406,7 +1443,8 @@ static inline int drop_nostate_event(enum ppm_event_type event_type,
 		 * The invalid fd events don't matter to userspace in dropping mode,
 		 * so we do this before the UF_NEVER_DROP check
 		 */
-		syscall_get_arguments(current, regs, 0, 1, &arg);
+		ppm_syscall_get_arguments(current, regs, args);
+		arg = args[0];
 		close_fd = (int)arg;
 
 		files = current->files;
@@ -1426,7 +1464,8 @@ static inline int drop_nostate_event(enum ppm_event_type event_type,
 	case PPME_SYSCALL_FCNTL_E:
 	case PPME_SYSCALL_FCNTL_X:
 		// cmd arg
-		syscall_get_arguments(current, regs, 1, 1, &arg);
+		ppm_syscall_get_arguments(current, regs, args);
+		arg = args[1];
 		if (arg != F_DUPFD && arg != F_DUPFD_CLOEXEC)
 			drop = true;
 		break;
@@ -1559,9 +1598,6 @@ static int record_event_consumer(struct ppm_consumer_t *consumer,
 			ASSERT(event_datap->event_info.context_data.sched_next != NULL);
 			ring_info->n_context_switches++;
 		}
-	} else if (event_datap->category == PPMC_SIGNAL) {
-		if (event_type == PPME_SIGNALDELIVER_E)
-			ASSERT(event_datap->event_info.signal_data.info != NULL);
 	}
 
 	/*
@@ -1698,8 +1734,9 @@ static int record_event_consumer(struct ppm_consumer_t *consumer,
 
 		if (event_datap->category == PPMC_SIGNAL) {
 			args.signo = event_datap->event_info.signal_data.sig;
-
-			if (args.signo == SIGKILL) {
+			if (event_datap->event_info.signal_data.info == NULL) {
+				args.spid = (__kernel_pid_t) 0;
+			} else if (args.signo == SIGKILL) {
 				args.spid = event_datap->event_info.signal_data.info->_sifields._kill._pid;
 			} else if (args.signo == SIGTERM || args.signo == SIGHUP || args.signo == SIGINT ||
 					args.signo == SIGTSTP || args.signo == SIGQUIT) {
@@ -2056,7 +2093,10 @@ TRACEPOINT_PROBE(signal_deliver_probe, int sig, struct siginfo *info, struct k_s
 
 	event_data.category = PPMC_SIGNAL;
 	event_data.event_info.signal_data.sig = sig;
-	event_data.event_info.signal_data.info = info;
+	if (info == SEND_SIG_NOINFO || info == SEND_SIG_PRIV)
+		event_data.event_info.signal_data.info = NULL;
+	else
+		event_data.event_info.signal_data.info = info;
 	event_data.event_info.signal_data.ka = ka;
 
 	record_event_all_consumers(PPME_SIGNALDELIVER_E, UF_USED | UF_ALWAYS_DROP, &event_data);
