@@ -23,8 +23,7 @@ or GPL2.txt for full copies of the license.
 /*
  * Macros for packing in different build environments
  */
-
-#if defined(_WIN64) || defined(WIN64) || defined(_WIN32) || defined(WIN32)
+#if !defined(CYGWING_AGENT) && (defined(_WIN64) || defined(WIN64) || defined(_WIN32) || defined(WIN32))
 #define _packed __pragma(pack(push, 1)); __pragma(pack(pop))
 #else
 #define _packed __attribute__((packed))
@@ -164,6 +163,8 @@ or GPL2.txt for full copies of the license.
 #define PPM_CL_CLONE_STOPPED (1 << 26)
 #define PPM_CL_CLONE_VFORK (1 << 27)
 #define PPM_CL_CLONE_NEWCGROUP (1 << 28)
+#define PPM_CL_CHILD_IN_PIDNS (1<<29)			/* true if the thread created by clone() is *not*
+									in the init pid namespace */
 
 /*
  * Futex Operations
@@ -326,6 +327,82 @@ or GPL2.txt for full copies of the license.
 #define PPM_FCNTL_F_OFD_SETLK 31
 #define PPM_FCNTL_F_OFD_SETLKW 32
 
+/*
+ * getsockopt/setsockopt levels
+ */
+#define PPM_SOCKOPT_LEVEL_UNKNOWN 0
+#define PPM_SOCKOPT_LEVEL_SOL_SOCKET 1
+#define PPM_SOCKOPT_LEVEL_SOL_TCP 2
+
+/*
+ * getsockopt/setsockopt options
+ * SOL_SOCKET only currently
+ */
+#define PPM_SOCKOPT_UNKNOWN	0
+#define PPM_SOCKOPT_SO_DEBUG	1
+#define PPM_SOCKOPT_SO_REUSEADDR	2
+#define PPM_SOCKOPT_SO_TYPE		3
+#define PPM_SOCKOPT_SO_ERROR	4
+#define PPM_SOCKOPT_SO_DONTROUTE	5
+#define PPM_SOCKOPT_SO_BROADCAST	6
+#define PPM_SOCKOPT_SO_SNDBUF	7
+#define PPM_SOCKOPT_SO_RCVBUF	8
+#define PPM_SOCKOPT_SO_SNDBUFFORCE	32
+#define PPM_SOCKOPT_SO_RCVBUFFORCE	33
+#define PPM_SOCKOPT_SO_KEEPALIVE	9
+#define PPM_SOCKOPT_SO_OOBINLINE	10
+#define PPM_SOCKOPT_SO_NO_CHECK	11
+#define PPM_SOCKOPT_SO_PRIORITY	12
+#define PPM_SOCKOPT_SO_LINGER	13
+#define PPM_SOCKOPT_SO_BSDCOMPAT	14
+#define PPM_SOCKOPT_SO_REUSEPORT	15
+#define PPM_SOCKOPT_SO_PASSCRED	16
+#define PPM_SOCKOPT_SO_PEERCRED	17
+#define PPM_SOCKOPT_SO_RCVLOWAT	18
+#define PPM_SOCKOPT_SO_SNDLOWAT	19
+#define PPM_SOCKOPT_SO_RCVTIMEO	20
+#define PPM_SOCKOPT_SO_SNDTIMEO	21
+#define PPM_SOCKOPT_SO_SECURITY_AUTHENTICATION		22
+#define PPM_SOCKOPT_SO_SECURITY_ENCRYPTION_TRANSPORT	23
+#define PPM_SOCKOPT_SO_SECURITY_ENCRYPTION_NETWORK		24
+#define PPM_SOCKOPT_SO_BINDTODEVICE	25
+#define PPM_SOCKOPT_SO_ATTACH_FILTER	26
+#define PPM_SOCKOPT_SO_DETACH_FILTER	27
+#define PPM_SOCKOPT_SO_PEERNAME		28
+#define PPM_SOCKOPT_SO_TIMESTAMP		29
+#define PPM_SOCKOPT_SO_ACCEPTCONN		30
+#define PPM_SOCKOPT_SO_PEERSEC		31
+#define PPM_SOCKOPT_SO_PASSSEC		34
+#define PPM_SOCKOPT_SO_TIMESTAMPNS		35
+#define PPM_SOCKOPT_SO_MARK			36
+#define PPM_SOCKOPT_SO_TIMESTAMPING		37
+#define PPM_SOCKOPT_SO_PROTOCOL		38
+#define PPM_SOCKOPT_SO_DOMAIN		39
+#define PPM_SOCKOPT_SO_RXQ_OVFL             40
+#define PPM_SOCKOPT_SO_WIFI_STATUS		41
+#define PPM_SOCKOPT_SO_PEEK_OFF		42
+#define PPM_SOCKOPT_SO_NOFCS		43
+#define PPM_SOCKOPT_SO_LOCK_FILTER		44
+#define PPM_SOCKOPT_SO_SELECT_ERR_QUEUE	45
+#define PPM_SOCKOPT_SO_BUSY_POLL		46
+#define PPM_SOCKOPT_SO_MAX_PACING_RATE	47
+#define PPM_SOCKOPT_SO_BPF_EXTENSIONS	48
+#define PPM_SOCKOPT_SO_INCOMING_CPU		49
+#define PPM_SOCKOPT_SO_ATTACH_BPF		50
+#define PPM_SOCKOPT_SO_PEERGROUPS		51
+#define PPM_SOCKOPT_SO_MEMINFO		52
+#define PPM_SOCKOPT_SO_COOKIE		53
+
+/*
+ * getsockopt/setsockopt dynamic params
+ */
+#define PPM_SOCKOPT_IDX_UNKNOWN 0
+#define PPM_SOCKOPT_IDX_ERRNO 1
+#define PPM_SOCKOPT_IDX_UINT32 2
+#define PPM_SOCKOPT_IDX_UINT64 3
+#define PPM_SOCKOPT_IDX_TIMEVAL 4
+#define PPM_SOCKOPT_IDX_MAX 5
+
  /*
  * ptrace requests
  */
@@ -863,7 +940,13 @@ enum ppm_event_type {
 	PPME_SYSCALL_LINK_2_X = 309,
 	PPME_SYSCALL_LINKAT_2_E = 310,
 	PPME_SYSCALL_LINKAT_2_X = 311,
-	PPM_EVENT_MAX = 312
+	PPME_SYSCALL_FCHMODAT_E = 312,
+	PPME_SYSCALL_FCHMODAT_X = 313,
+	PPME_SYSCALL_CHMOD_E = 314,
+	PPME_SYSCALL_CHMOD_X = 315,
+	PPME_SYSCALL_FCHMOD_E = 316,
+	PPME_SYSCALL_FCHMOD_X = 317,
+	PPM_EVENT_MAX = 318
 };
 /*@}*/
 
@@ -1281,7 +1364,8 @@ enum ppm_param_type {
 	PT_IPV6NET = 39, /* An IPv6 network. */
 	PT_IPADDR = 40,  /* Either an IPv4 or IPv6 address. The length indicates which one it is. */
 	PT_IPNET = 41,  /* Either an IPv4 or IPv6 network. The length indicates which one it is. */
-	PT_MAX = 42 /* array size */
+	PT_MODE = 42, /* a 32 bit bitmask to represent file modes. */
+	PT_MAX = 43 /* array size */
 };
 
 enum ppm_print_format {
@@ -1378,6 +1462,8 @@ struct ppm_evt_hdr {
 #define PPM_IOCTL_ENABLE_PAGE_FAULTS _IO(PPM_IOCTL_MAGIC, 19)
 #define PPM_IOCTL_GET_N_TRACEPOINT_HIT _IO(PPM_IOCTL_MAGIC, 20)
 #define PPM_IOCTL_GET_PROBE_VERSION _IO(PPM_IOCTL_MAGIC, 21)
+#define PPM_IOCTL_SET_FULLCAPTURE_PORT_RANGE _IO(PPM_IOCTL_MAGIC, 22)
+#define PPM_IOCTL_SET_STATSD_PORT _IO(PPM_IOCTL_MAGIC, 23)
 #endif // CYGWING_AGENT
 
 extern const struct ppm_name_value socket_families[];
@@ -1392,6 +1478,8 @@ extern const struct ppm_name_value umount_flags[];
 extern const struct ppm_name_value shutdown_how[];
 extern const struct ppm_name_value rlimit_resources[];
 extern const struct ppm_name_value fcntl_commands[];
+extern const struct ppm_name_value sockopt_levels[];
+extern const struct ppm_name_value sockopt_options[];
 extern const struct ppm_name_value ptrace_requests[];
 extern const struct ppm_name_value prot_flags[];
 extern const struct ppm_name_value mmap_flags[];
@@ -1407,7 +1495,9 @@ extern const struct ppm_name_value access_flags[];
 extern const struct ppm_name_value pf_flags[];
 extern const struct ppm_name_value unlinkat_flags[];
 extern const struct ppm_name_value linkat_flags[];
+extern const struct ppm_name_value chmod_mode[];
 
+extern const struct ppm_param_info sockopt_dynamic_param[];
 extern const struct ppm_param_info ptrace_dynamic_param[];
 extern const struct ppm_param_info bpf_dynamic_param[];
 
@@ -1512,5 +1602,6 @@ struct ppm_event_entry {
 
 #define RW_SNAPLEN 80
 #define RW_MAX_SNAPLEN PPM_MAX_ARG_SIZE
+#define RW_MAX_FULLCAPTURE_PORT_SNAPLEN 16000
 
 #endif /* EVENTS_PUBLIC_H_ */
