@@ -18,6 +18,9 @@ limitations under the License.
 */
 
 
+#include <stdio.h>
+#include <stdlib.h>
+
 #ifndef _WIN32
 #include <unistd.h>
 #include <sys/uio.h>
@@ -28,9 +31,6 @@ struct iovec {
 };
 #endif
 
-#include <stdio.h>
-#include <stdlib.h>
-
 #include "scap.h"
 #include "scap-int.h"
 #include "scap_savefile.h"
@@ -825,7 +825,7 @@ int32_t scap_setup_dump(scap_t *handle, scap_dumper_t* d, const char *fname)
 		scap_proc_free_table(handle);
 		char filename[SCAP_MAX_PATH_SIZE];
 		snprintf(filename, sizeof(filename), "%s/proc", scap_get_host_root());
-		if(scap_proc_scan_proc_dir(handle, filename, -1, -1, NULL, handle->m_lasterr, true) != SCAP_SUCCESS)
+		if(scap_proc_scan_proc_dir(handle, filename, handle->m_lasterr) != SCAP_SUCCESS)
 		{
 			handle->m_proc_callback = tcb;
 			return SCAP_FAILURE;
