@@ -96,6 +96,7 @@ uint32_t lua_cbacks::rawval_to_lua_stack(lua_State *ls, uint8_t* rawval, ppm_par
 			return 1;
 		case PT_FLAGS32:
 		case PT_UINT32:
+		case PT_MODE:
 		case PT_UID:
 		case PT_GID:
 			lua_pushnumber(ls, *(uint32_t*)rawval);
@@ -919,7 +920,7 @@ int lua_cbacks::get_thread_table_int(lua_State *ls, bool include_fds, bool bareb
 		//
 		lua_pushstring(ls, "fdtable");
 		lua_newtable(ls);
-		
+
 		if(include_fds)
 		{
 			for(fdit = fdtable->m_table.begin(); fdit != fdtable->m_table.end(); ++fdit)
@@ -1185,6 +1186,22 @@ int lua_cbacks::get_container_table(lua_State *ls)
 		{
 			lua_pushstring(ls, "rkt");
 		}
+		else if(it->second.m_type == CT_CRI)
+		{
+			lua_pushstring(ls, "cri");
+		}
+		else if(it->second.m_type == CT_CONTAINERD)
+		{
+			lua_pushstring(ls, "containerd");
+		}
+		else if(it->second.m_type == CT_CRIO)
+		{
+			lua_pushstring(ls, "cri-o");
+		}
+		else if(it->second.m_type == CT_BPM)
+		{
+			lua_pushstring(ls, "bpm");
+		}
 		else
 		{
 			ASSERT(false);
