@@ -24,9 +24,23 @@ limitations under the License.
 #define VISIBILITY_PRIVATE private:
 #endif
 
+#include "sinsp_inet.h"
+#include "sinsp_public.h"
+#include "scap.h"
+#include "gen_filter.h"
+#include "../../driver/ppm_events_public.h"
+#include "settings.h"
+
 typedef class sinsp sinsp;
 typedef class sinsp_threadinfo sinsp_threadinfo;
 
+
+namespace test_helpers {
+	class event_builder;
+	class sinsp_mock;
+}
+
+
 ///////////////////////////////////////////////////////////////////////////////
 // Event arguments
 ///////////////////////////////////////////////////////////////////////////////
@@ -92,7 +106,7 @@ private:
   events and their parameters, including parsing, formatting and extracting
   state like the event process or FD.
 */
-class SINSP_PUBLIC sinsp_evt
+class SINSP_PUBLIC sinsp_evt : public gen_event
 {
 public:
 	/*!
@@ -145,6 +159,14 @@ public:
 	sinsp_evt(sinsp* inspector);
 	~sinsp_evt();
 
+	/*!
+	  \brief Set the inspector.
+	*/
+	void inspector(sinsp *value)
+	{
+		m_inspector = value;
+	}
+
 	/*!
 	  \brief Get the incremental number of this event.
 	*/
@@ -300,7 +322,7 @@ public:
 	   before returning it. For example, and FD number will be converted into
 	   the correspondent file, TCP tuple, etc.
 	*/
-	string get_param_value_str(const string& name, bool resolved = true);
+	std::string get_param_value_str(const std::string& name, bool resolved = true);
 
 	/*!
 	  \brief Return the event's category, based on the event type and the FD on
@@ -308,16 +330,6 @@ public:
 	*/
 	void get_category(OUT sinsp_evt::category* cat);
 
-	/*!
-	  \brief Set an opaque "check id", corresponding to the id of the last filtercheck that matched this event.
-	*/
-	void set_check_id(int32_t id);
-
-	/*!
-	  \brief Get the opaque "check id" (-1 if not set).
-	*/
-	int32_t get_check_id();
-
 #ifdef HAS_FILTERING
 	/*!
 	  \brief Return true if the event has been rejected by the filtering system.
@@ -334,6 +346,11 @@ public:
 
 	bool falco_consider();
 
+	inline uint16_t get_source()
+	{
+		return ESRC_SINSP;
+	}
+
 // Doxygen doesn't understand VISIBILITY_PRIVATE
 #ifdef _DOXYGEN
 private:
@@ -350,6 +367,7 @@ private:
 	{
 		m_flags = EF_NONE;
 		m_info = &(m_event_info_table[m_pevt->type]);
+		m_tinfo_ref.reset();
 		m_tinfo = NULL;
 		m_fdinfo = NULL;
 		m_fdinfo_name_changed = false;
@@ -361,6 +379,7 @@ private:
 		m_flags = EF_NONE;
 		m_pevt = (scap_evt *)evdata;
 		m_info = &(m_event_info_table[m_pevt->type]);
+		m_tinfo_ref.reset();
 		m_tinfo = NULL;
 		m_fdinfo = NULL;
 		m_fdinfo_name_changed = false;
@@ -369,6 +388,17 @@ private:
 		m_evtnum = 0;
 		m_poriginal_evt = NULL;
 	}
+	inline void init(scap_evt *scap_event,
+			 ppm_event_info * ppm_event,
+			 sinsp_threadinfo *threadinfo,
+			 sinsp_fdinfo_t *fdinfo)
+	{
+		m_pevt = scap_event;
+		m_info = ppm_event;
+		m_tinfo_ref.reset(); // we don't own the threadinfo so don't try to manage its lifetime
+		m_tinfo = threadinfo;
+		m_fdinfo = fdinfo;
+	}
 	inline void load_params()
 	{
 		uint32_t j;
@@ -392,8 +422,8 @@ private:
 			valptr += lens[j];
 		}
 	}
-	string get_param_value_str(uint32_t id, bool resolved);
-	string get_param_value_str(const char* name, bool resolved = true);
+	std::string get_param_value_str(uint32_t id, bool resolved);
+	std::string get_param_value_str(const char* name, bool resolved = true);
 	char* render_fd(int64_t fd, const char** resolved_str, sinsp_evt::param_fmt fmt);
 	int render_fd_json(Json::Value *ret, int64_t fd, const char** resolved_str, sinsp_evt::param_fmt fmt);
 	uint32_t get_dump_flags();
@@ -409,17 +439,20 @@ VISIBILITY_PRIVATE
 	sinsp* m_inspector;
 	scap_evt* m_pevt;
 	scap_evt* m_poriginal_evt;	// This is used when the original event is replaced by a different one (e.g. in the case of user events)
+	char *m_pevt_storage;           // In some cases an alternate buffer is used to hold m_pevt. This points to that storage.
 	uint16_t m_cpuid;
 	uint64_t m_evtnum;
 	uint32_t m_flags;
-	int32_t m_check_id = 0;
 	bool m_params_loaded;
 	const struct ppm_event_info* m_info;
-	vector<sinsp_evt_param> m_params;
+	std::vector<sinsp_evt_param> m_params;
 
-	vector<char> m_paramstr_storage;
-	vector<char> m_resolved_paramstr_storage;
+	std::vector<char> m_paramstr_storage;
+	std::vector<char> m_resolved_paramstr_storage;
 
+	// reference to keep threadinfo alive. currently only used for synthetic container event thread info
+	// it should either be null, or point to the same place as m_tinfo
+	std::shared_ptr<sinsp_threadinfo> m_tinfo_ref;
 	sinsp_threadinfo* m_tinfo;
 	sinsp_fdinfo_t* m_fdinfo;
 
@@ -455,6 +488,8 @@ VISIBILITY_PRIVATE
 	friend class capture_job;
 	friend class sinsp_memory_dumper;
 	friend class sinsp_memory_dumper_job;
+	friend class test_helpers::event_builder;
+	friend class test_helpers::sinsp_mock;
 };
 
 /*@}*/
