@@ -467,6 +467,7 @@ bool flt_compare(cmpop op, ppm_param_type type, void* operand1, void* operand2,
 		return flt_compare_uint64(op, (uint64_t)*(uint16_t*)operand1, (uint64_t)*(uint16_t*)operand2);
 	case PT_UINT32:
 	case PT_FLAGS32:
+	case PT_MODE:
 	case PT_BOOL:
 	case PT_IPV4ADDR:
 		return flt_compare_uint64(op, (uint64_t)*(uint32_t*)operand1, (uint64_t)*(uint32_t*)operand2);
@@ -598,6 +599,7 @@ bool flt_compare_avg(cmpop op,
 		return flt_compare_uint64(op, u641, u642);
 	case PT_UINT32:
 	case PT_FLAGS32:
+	case PT_MODE:
 	case PT_BOOL:
 	case PT_IPV4ADDR:
 	case PT_IPV6ADDR:
@@ -1191,17 +1193,6 @@ int32_t sinsp_filter_check::parse_field_name(const char* str, bool alloc_state,
 	return max_fldlen;
 }
 
-void sinsp_filter_check::set_check_id(int32_t id)
-{
-	m_check_id = id;
-}
-
-int32_t sinsp_filter_check::get_check_id()
-{
-	return m_check_id;
-}
-
-
 void sinsp_filter_check::add_filter_value(const char* str, uint32_t len, uint32_t i)
 {
 	size_t parsed_len;
@@ -1275,6 +1266,7 @@ bool sinsp_filter_check::flt_compare(cmpop op, ppm_param_type type, void* operan
 		{
 		case PT_IPV4NET:
 		case PT_IPV6NET:
+		case PT_IPNET:
 		case PT_SOCKADDR:
 		case PT_SOCKTUPLE:
 		case PT_FDLIST:
@@ -1285,7 +1277,9 @@ bool sinsp_filter_check::flt_compare(cmpop op, ppm_param_type type, void* operan
 				if (::flt_compare(CO_EQ,
 						  type,
 						  operand1,
-						  filter_value_p(i)))
+						  filter_value_p(i),
+						  op1_len,
+						  filter_value(i).size()))
 				{
 					return true;
 				}
@@ -1334,6 +1328,16 @@ bool sinsp_filter_check::flt_compare(cmpop op, ppm_param_type type, void* operan
 	}
 }
 
+uint8_t* sinsp_filter_check::extract(gen_event *evt, OUT uint32_t* len, bool sanitize_strings)
+{
+	return extract((sinsp_evt *) evt, len, sanitize_strings);
+}
+
+bool sinsp_filter_check::compare(gen_event *evt)
+{
+	return compare((sinsp_evt *) evt);
+}
+
 bool sinsp_filter_check::compare(sinsp_evt *evt)
 {
 	uint32_t evt_val_len=0;
@@ -1352,176 +1356,13 @@ bool sinsp_filter_check::compare(sinsp_evt *evt)
 			   m_val_storage_len);
 }
 
-///////////////////////////////////////////////////////////////////////////////
-// sinsp_filter_expression implementation
-///////////////////////////////////////////////////////////////////////////////
-sinsp_filter_expression::sinsp_filter_expression()
-{
-	m_parent = NULL;
-}
-
-sinsp_filter_expression::~sinsp_filter_expression()
-{
-	uint32_t j;
-
-	for(j = 0; j < m_checks.size(); j++)
-	{
-		delete m_checks[j];
-	}
-}
-
-// Only filter checks get IDs
-int32_t sinsp_filter_expression::get_check_id()
-{
-	return 0;
-}
-
-sinsp_filter_check* sinsp_filter_expression::allocate_new()
-{
-	ASSERT(false);
-	return NULL;
-}
-
-void sinsp_filter_expression::add_check(sinsp_filter_check* chk)
-{
-	m_checks.push_back(chk);
-}
-
-void sinsp_filter_expression::parse(string expr)
-{
-}
-
-bool sinsp_filter_expression::compare(sinsp_evt *evt)
-{
-	uint32_t j;
-	uint32_t size = (uint32_t)m_checks.size();
-	bool res = true;
-	sinsp_filter_check* chk = NULL;
-
-	for(j = 0; j < size; j++)
-	{
-		chk = m_checks[j];
-		ASSERT(chk != NULL);
-
-		if(j == 0)
-		{
-			switch(chk->m_boolop)
-			{
-			case BO_NONE:
-				res = chk->compare(evt);
-				if (res) {
-					evt->set_check_id(chk->get_check_id());
-				}
-				break;
-			case BO_NOT:
-				res = !chk->compare(evt);
-				break;
-			default:
-				ASSERT(false);
-				break;
-			}
-		}
-		else
-		{
-			switch(chk->m_boolop)
-			{
-			case BO_OR:
-				if(res)
-				{
-					goto done;
-				}
-				res = chk->compare(evt);
-				if (res) {
-					evt->set_check_id(chk->get_check_id());
-				}
-				break;
-			case BO_AND:
-				if(!res)
-				{
-					goto done;
-				}
-				res = chk->compare(evt);
-				if (res) {
-					evt->set_check_id(chk->get_check_id());
-				}
-				break;
-			case BO_ORNOT:
-				if(res)
-				{
-					goto done;
-				}
-				res = !chk->compare(evt);
-				if (res) {
-					evt->set_check_id(chk->get_check_id());
-				}
-				break;
-			case BO_ANDNOT:
-				if(!res)
-				{
-					goto done;
-				}
-				res = !chk->compare(evt);
-				if (res) {
-					evt->set_check_id(chk->get_check_id());
-				}
-				break;
-			default:
-				ASSERT(false);
-				break;
-			}
-		}
-	}
- done:
-
-	return res;
-}
-
-///////////////////////////////////////////////////////////////////////////////
-// sinsp_filter implementation
-///////////////////////////////////////////////////////////////////////////////
-sinsp_filter::sinsp_filter(sinsp* inspector)
+sinsp_filter::sinsp_filter(sinsp *inspector)
 {
 	m_inspector = inspector;
-	m_filter = new sinsp_filter_expression();
-	m_curexpr = m_filter;
-
 }
 
 sinsp_filter::~sinsp_filter()
 {
-	if(m_filter)
-	{
-		delete m_filter;
-	}
-}
-
-void sinsp_filter::push_expression(boolop op)
-{
-	sinsp_filter_expression* newexpr = new sinsp_filter_expression();
-	newexpr->m_boolop = op;
-	newexpr->m_parent = m_curexpr;
-
-	add_check((sinsp_filter_check*)newexpr);
-	m_curexpr = newexpr;
-}
-
-void sinsp_filter::pop_expression()
-{
-	ASSERT(m_curexpr->m_parent != NULL);
-
-	m_curexpr = m_curexpr->m_parent;
-}
-
-bool sinsp_filter::run(sinsp_evt *evt)
-{
-	//	printf("m_filter: %p", (void*) m_filter);
-	//	ASSERT(m_filter != NULL);
-	return m_filter->compare(evt);
-}
-
-void sinsp_filter::add_check(sinsp_filter_check* chk)
-{
-	m_curexpr->add_check(chk);
 }
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -2498,4 +2339,27 @@ void sinsp_evttype_filter::syscalls_for_ruleset(std::vector<bool> &syscalls, uin
 	return m_rulesets[ruleset]->syscalls_for_ruleset(syscalls);
 }
 
+sinsp_filter_factory::sinsp_filter_factory(sinsp *inspector)
+	: m_inspector(inspector)
+{
+}
+
+sinsp_filter_factory::~sinsp_filter_factory()
+{
+}
+
+gen_event_filter *sinsp_filter_factory::new_filter()
+{
+	return new sinsp_filter(m_inspector);
+}
+
+
+gen_event_filter_check *sinsp_filter_factory::new_filtercheck(const char *fldname)
+{
+	return g_filterlist.new_filter_check_from_fldname(fldname,
+							  m_inspector,
+							  true);
+}
+
+
 #endif // HAS_FILTERING
