@@ -33,7 +33,7 @@ extern sinsp_filter_check_list g_filterlist;
 
 // It would be nice to expose this up to Lua so that comparison operator
 // parsing/encoding can be done there.
-cmpop string_to_cmpop(const char* str)
+static cmpop string_to_cmpop(const char* str)
 {
 	if(strcmp(str, "=") == 0)
 	{
@@ -119,122 +119,126 @@ boolop string_to_boolop(const char* str)
 
 int lua_parser_cbacks::nest(lua_State *ls)
 {
-	lua_getglobal(ls, "siparser");
+	lua_parser* parser = (lua_parser*)lua_topointer(ls, -1);
 
-	lua_parser* parser = (lua_parser*)lua_touserdata(ls, -1);
-	lua_pop(ls, 1);
+	try {
 
-	if (parser->m_have_rel_expr && parser->m_last_boolop == BO_NONE)
+		if (parser->m_have_rel_expr && parser->m_last_boolop == BO_NONE)
+		{
+			string err = "filter.nest() called without a preceding call to filter.bool_op()";
+			throw sinsp_exception(err);
+		}
+
+		gen_event_filter* filter = parser->m_filter;
+
+		filter->push_expression(parser->m_last_boolop);
+		parser->m_nest_level++;
+
+		parser->m_last_boolop = BO_NONE;
+		parser->m_have_rel_expr = false;
+	}
+	catch (exception &e)
 	{
-		string err = "filter.nest() called without a preceding call to filter.bool_op()";
-		fprintf(stderr, "%s\n", err.c_str());
-		throw sinsp_exception(err);
+		lua_pushstring(ls, e.what());
+		lua_error(ls);
 	}
-
-	sinsp_filter* filter = parser->m_filter;
-
-	filter->push_expression(parser->m_last_boolop);
-	parser->m_nest_level++;
-
-	parser->m_last_boolop = BO_NONE;
-	parser->m_have_rel_expr = false;
 
 	return 0;
 }
 
 int lua_parser_cbacks::unnest(lua_State *ls)
 {
-	lua_getglobal(ls, "siparser");
+	lua_parser* parser = (lua_parser*)lua_topointer(ls, -1);
 
-	lua_parser* parser = (lua_parser*)lua_touserdata(ls, -1);
-	lua_pop(ls, 1);
+	try {
 
-	if (parser->m_nest_level < 1)
+		if (parser->m_nest_level < 1)
+		{
+			string err = "filter.unnest() called without being nested";
+			throw sinsp_exception(err);
+		}
+
+		gen_event_filter* filter = parser->m_filter;
+
+		filter->pop_expression();
+		parser->m_nest_level--;
+	}
+	catch (exception &e)
 	{
-		string err = "filter.unnest() called without being nested";
-		fprintf(stderr, "%s\n", err.c_str());
-		throw sinsp_exception(err);
+		lua_pushstring(ls, e.what());
+		lua_error(ls);
 	}
-
-	sinsp_filter* filter = parser->m_filter;
-
-	filter->pop_expression();
-	parser->m_nest_level--;
 
 	return 0;
 }
 
 int lua_parser_cbacks::bool_op(lua_State *ls)
 {
-	lua_getglobal(ls, "siparser");
+	lua_parser* parser = (lua_parser*)lua_topointer(ls, -2);
 
-	lua_parser* parser = (lua_parser*)lua_touserdata(ls, -1);
-	lua_pop(ls, 1);
+	try {
 
-	const char* opstr = luaL_checkstring(ls, 1);
-	boolop op = string_to_boolop(opstr);
+		const char* opstr = luaL_checkstring(ls, -1);
+		boolop op = string_to_boolop(opstr);
 
-	if (!parser->m_have_rel_expr)
-	{
-		if (op == BO_NOT) {
-			op = (boolop)((uint32_t)parser->m_last_boolop | op);
-		}
-		else
+		if (!parser->m_have_rel_expr)
 		{
-			string err = "filter.bool_op() called without having called rel_expr() ";
-			fprintf(stderr, "%s\n", err.c_str());
-			throw sinsp_exception(err);
+			if (op == BO_NOT) {
+				op = (boolop)((uint32_t)parser->m_last_boolop | op);
+			}
+			else
+			{
+				string err = "filter.bool_op() called without having called rel_expr() ";
+				throw sinsp_exception(err);
+			}
 		}
-	}
 
-	if (parser->m_last_boolop != BO_NONE)
-	{
-		if (op == BO_NOT) {
-			op = (boolop)((uint32_t)parser->m_last_boolop | op);
-		}
-		else
+		if (parser->m_last_boolop != BO_NONE)
 		{
-			string err = "filter.bool_op() called twice in a row";
-			fprintf(stderr, "%s\n", err.c_str());
-			throw sinsp_exception(err);
+			if (op == BO_NOT) {
+				op = (boolop)((uint32_t)parser->m_last_boolop | op);
+			}
+			else
+			{
+				string err = "filter.bool_op() called twice in a row";
+				throw sinsp_exception(err);
+			}
 		}
+		parser->m_last_boolop = op;
+
+	}
+	catch (exception &e)
+	{
+		lua_pushstring(ls, e.what());
+		lua_error(ls);
 	}
-	parser->m_last_boolop = op;
 	return 0;
 
 }
 
 int lua_parser_cbacks::rel_expr(lua_State *ls)
 {
-	lua_getglobal(ls, "siparser");
+	lua_parser* parser = (lua_parser*)lua_topointer(ls, 1);
 
-	lua_parser* parser = (lua_parser*)lua_touserdata(ls, -1);
-	lua_pop(ls, 1);
+	try {
 
-	if (parser->m_have_rel_expr && parser->m_last_boolop == BO_NONE)
-	{
-		string err = "filter.rel_expr() called twice in a row";
-		fprintf(stderr, "%s\n", err.c_str());
-		throw sinsp_exception(err);
-	}
+		if (parser->m_have_rel_expr && parser->m_last_boolop == BO_NONE)
+		{
+			string err = "filter.rel_expr() called twice in a row";
+			throw sinsp_exception(err);
+		}
 
-	parser->m_have_rel_expr = true;
-	sinsp* inspector = parser->m_inspector;
-	sinsp_filter* filter = parser->m_filter;
+		parser->m_have_rel_expr = true;
+		gen_event_filter* filter = parser->m_filter;
 
-	const char* fld = luaL_checkstring(ls, 1);
-	sinsp_filter_check* chk = g_filterlist.new_filter_check_from_fldname(fld,
-									     inspector,
-									     true);
-	if(chk == NULL)
-	{
-		string err = "filter_check called with nonexistent field " + string(fld);
-		fprintf(stderr, "%s\n", err.c_str());
-		throw sinsp_exception("parser API error");
-	}
+		const char* fld = luaL_checkstring(ls, 2);
+		gen_event_filter_check *chk = parser->m_factory.new_filtercheck(fld);
+		if(chk == NULL)
+		{
+			string err = "filter_check called with nonexistent field " + string(fld);
+			throw sinsp_exception("parser API error");
+		}
 
-	try
-	{
 		int i;
 		int rule_index = 0;
 
@@ -243,7 +247,7 @@ int lua_parser_cbacks::rel_expr(lua_State *ls)
 
 		chk->parse_field_name(fld, true, true);
 
-		const char* cmpop = luaL_checkstring(ls, 2);
+		const char* cmpop = luaL_checkstring(ls, 3);
 		chk->m_cmpop = string_to_cmpop(cmpop);
 
 		// "exists" is the only unary comparison op
@@ -251,37 +255,36 @@ int lua_parser_cbacks::rel_expr(lua_State *ls)
 		{
 			if (strcmp(cmpop, "in") == 0 || strcmp(cmpop, "pmatch") == 0)
 			{
-				if (!lua_istable(ls, 3))
+				if (!lua_istable(ls, 4))
 				{
 					string err = "Got non-table as in-expression operand\n";
-					fprintf(stderr, "%s\n", err.c_str());
 					throw sinsp_exception("parser API error");
 				}
-				int n = luaL_getn(ls, 3);  /* get size of table */
+				int n = luaL_getn(ls, 4);  /* get size of table */
 				for (i=1; i<=n; i++)
 				{
-					lua_rawgeti(ls, 3, i);
-					const char* value = luaL_checkstring(ls, 5);
+					lua_rawgeti(ls, 4, i);
+					const char* value = luaL_checkstring(ls, 6);
 					chk->add_filter_value(value, strlen(value), i - 1);
 					lua_pop(ls, 1);
 				}
 			}
 			else
 			{
-				const char* value = luaL_checkstring(ls, 3);
+				const char* value = luaL_checkstring(ls, 4);
 				chk->add_filter_value(value, strlen(value));
 			}
 
-			if (lua_isnumber(ls, 4))
+			if (lua_isnumber(ls, 5))
 			{
-				rule_index = (int) luaL_checkinteger(ls, 4);
+				rule_index = (int) luaL_checkinteger(ls, 5);
 			}
 		}
 		else
 		{
-			if (lua_isnumber(ls, 3))
+			if (lua_isnumber(ls, 4))
 			{
-				rule_index = (int) luaL_checkinteger(ls, 3);
+				rule_index = (int) luaL_checkinteger(ls, 4);
 			}
 		}
 
@@ -289,14 +292,15 @@ int lua_parser_cbacks::rel_expr(lua_State *ls)
 		{
 			chk->set_check_id(rule_index);
 		}
-	}
-	catch(sinsp_exception& e)
-	{
-		fprintf(stderr, "Error in filter.rel_expr() %s\n\n", e.what());
-		throw e;
-	}
 
-	filter->add_check(chk);
+		filter->add_check(chk);
+
+	}
+	catch (exception &e)
+	{
+		lua_pushstring(ls, e.what());
+		lua_error(ls);
+	}
 
 	return 0;
 }
