@@ -1,19 +1,20 @@
 /*
-Copyright (C) 2013-2016 Draios inc.
+Copyright (C) 2013-2018 Draios Inc dba Sysdig.
 
 This file is part of sysdig.
 
-sysdig is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License version 2 as
-published by the Free Software Foundation.
+Licensed under the Apache License, Version 2.0 (the "License");
+you may not use this file except in compliance with the License.
+You may obtain a copy of the License at
 
-sysdig is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
+    http://www.apache.org/licenses/LICENSE-2.0
+
+Unless required by applicable law or agreed to in writing, software
+distributed under the License is distributed on an "AS IS" BASIS,
+WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+See the License for the specific language governing permissions and
+limitations under the License.
 
-You should have received a copy of the GNU General Public License
-along with sysdig.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 #pragma once
@@ -183,6 +184,7 @@ void path_prefix_map<Value>::add_search_path_components(const path_prefix_map_ut
 			// can drop the existing subtree. For example, we can
 			// drop /usr/lib when adding /usr.
 			delete(it->second.first);
+			delete(it->second.second);
 			m_dirs.erase(*cur);
 			m_dirs[*cur] = std::pair<path_prefix_map*,Value*>(NULL, new Value(v));
 		}
