@@ -42,17 +42,17 @@ limitations under the License.
 */
 
 #pragma once
+
+#include "capture_stats_source.h"
+
 #ifdef _WIN32
 #pragma warning(disable: 4251 4200 4221 4190)
 #endif
 
-#ifdef _WIN32
-#define SINSP_PUBLIC __declspec(dllexport)
-#include <Ws2tcpip.h>
-#else
-#define SINSP_PUBLIC
-#include <arpa/inet.h>
-#endif
+#include "tbb/concurrent_queue.h"
+
+#include "sinsp_inet.h"
+#include "sinsp_public.h"
 
 #define __STDC_FORMAT_MACROS
 
@@ -80,28 +80,21 @@ using namespace std;
 #include "utils.h"
 
 #ifndef VISIBILITY_PRIVATE
+// Some code defines VISIBILITY_PRIVATE to nothing to get private access to sinsp
 #define VISIBILITY_PRIVATE private:
+#define VISIBILITY_PROTECTED protected:
+#else
+#define VISIBILITY_PROTECTED
 #endif
 
 #define ONE_SECOND_IN_NS 1000000000LL
 
-//
-// Protocol decoder callback type
-//
-typedef enum sinsp_pd_callback_type
-{
-	CT_OPEN,
-	CT_CONNECT,
-	CT_READ,
-	CT_WRITE,
-	CT_TUPLE_CHANGE,
-}sinsp_pd_callback_type;
-
 #include "tuples.h"
 #include "fdinfo.h"
 #include "threadinfo.h"
 #include "ifinfo.h"
 #include "eventformatter.h"
+#include "sinsp_pd_callback_type.h"
 
 class sinsp_partial_transaction;
 class sinsp_parser;
@@ -124,7 +117,7 @@ class k8s_handler;
 class k8s_api_handler;
 #endif // HAS_CAPTURE
 
-vector<string> sinsp_split(const string &s, char delim);
+std::vector<std::string> sinsp_split(const std::string &s, char delim);
 
 /*!
   \brief Information about a chisel
@@ -132,8 +125,8 @@ vector<string> sinsp_split(const string &s, char delim);
 class sinsp_chisel_details
 {
 public:
-	string m_name;
-	vector<pair<string, string>> m_args;
+	std::string m_name;
+	std::vector<pair<std::string, std::string>> m_args;
 };
 
 /*!
@@ -238,14 +231,15 @@ public:
   - event retrieval
   - setting capture filters
 */
-class SINSP_PUBLIC sinsp
+class SINSP_PUBLIC sinsp : public capture_stats_source
 {
 public:
+	typedef std::shared_ptr<sinsp> ptr;
 	typedef std::set<std::string> k8s_ext_list_t;
 	typedef std::shared_ptr<k8s_ext_list_t> k8s_ext_list_ptr_t;
 
 	sinsp();
-	~sinsp();
+	virtual ~sinsp();
 
 	/*!
 	  \brief Start a live event capture.
@@ -256,7 +250,7 @@ public:
 	  @throws a sinsp_exception containing the error string is thrown in case
 	   of failure.
 	*/
-	void open(uint32_t timeout_ms = SCAP_TIMEOUT_MS);
+	virtual void open(uint32_t timeout_ms = SCAP_TIMEOUT_MS);
 
 	/*!
 	  \brief Start an event capture from a trace file.
@@ -266,7 +260,7 @@ public:
 	  @throws a sinsp_exception containing the error string is thrown in case
 	   of failure.
 	*/
-	void open(string filename);
+	void open(const std::string &filename);
 
 	/*!
 	  \brief Start an event capture from a file descriptor.
@@ -298,9 +292,9 @@ public:
 	   obtain the cause of the error.
 
 	  \note: the returned event can be considered valid only until the next
-	   call to \ref next()
+	   call to \ref)
 	*/
-	int32_t next(OUT sinsp_evt** evt);
+	virtual int32_t next(OUT sinsp_evt **evt);
 
 	/*!
 	  \brief Get the number of events that have been captured and processed
@@ -459,7 +453,7 @@ public:
 	  \brief Populate the given vector with the full list of filter check fields
 	   that this version of the library supports.
 	*/
-	static void get_filtercheck_fields_info(vector<const filter_check_info*>* list);
+	static void get_filtercheck_fields_info(std::vector<const filter_check_info*>* list);
 
 	bool has_metrics();
 
@@ -553,7 +547,7 @@ public:
 
 	  \note this call won't work on file captures.
 	*/
-	void get_capture_stats(scap_stats* stats);
+	void get_capture_stats(scap_stats* stats) override;
 
 	void set_max_thread_table_size(uint32_t value);
 
@@ -594,7 +588,7 @@ public:
 	/*!
 	  \brief Get the list of machine network interfaces.
 
-	  \return Pointer to the iterface list manager.
+	  \return Pointer to the interface list manager.
 	*/
 	sinsp_network_interfaces* get_ifaddr_list();
 
@@ -632,13 +626,30 @@ public:
 	}
 
 	/*!
-	  \brief Returns true if the current capture is live
+	  \brief Returns true if the sysdig module is not loaded
 	*/
 	inline bool is_nodriver()
 	{
 		return m_mode == SCAP_MODE_NODRIVER;
 	}
 
+	/*!
+	  \brief Returns true if truncated environments should be loaded from /proc
+	*/
+	inline bool large_envs_enabled()
+	{
+		return is_live() && m_large_envs_enabled;
+	}
+
+	/*!
+	  \brief Enable/disable large environment support
+
+	  \param enable when it is true and the current capture is live
+	  environments larger than SCAP_MAX_ENV_SIZE will be loaded
+	  from /proc/<pid>/environ (if possible)
+	*/
+	void set_large_envs(bool enable);
+
 	/*!
 	  \brief Set the debugging mode of the inspector.
 
@@ -696,7 +707,7 @@ public:
 	/*!
 	  \brief Sets the max length of event argument strings.
 
-	  \param len Max length after which an avent argument string is truncated.
+	  \param len Max length after which an event argument string is truncated.
 	   0 means no limit. Use this to reduce verbosity when printing event info
 	   on screen.
 	*/
@@ -713,7 +724,7 @@ public:
 	/*!
 	  \brief Set a flag indicating if the command line requested to show container information.
 
-	  \param set true if the command line arugment is set to show container information
+	  \param set true if the command line argument is set to show container information
 	*/
 	void set_print_container_data(bool print_container_data);
 
@@ -731,7 +742,7 @@ public:
 
 	  \param the name of the required decoder
 	*/
-	sinsp_protodecoder* require_protodecoder(string decoder_name);
+	sinsp_protodecoder* require_protodecoder(std::string decoder_name);
 
 	/*!
 	  \brief Lets a filter plugin request a protocol decoder.
@@ -744,7 +755,7 @@ public:
 	  \brief If this is an offline capture, return the name of the file that is
 	   being read, otherwise return an empty string.
 	*/
-	string get_input_filename()
+	std::string get_input_filename()
 	{
 		return m_input_filename;
 	}
@@ -752,7 +763,7 @@ public:
 	/*!
 	  \brief If this is an online capture, set event_id.
 	  \param event type to set
-	  \return SCAP_SUCCESS if the call is succesful
+	  \return SCAP_SUCCESS if the call is successful
 	   On Failure, SCAP_FAILURE is returned and getlasterr() can be used to
 	   obtain the cause of the error.
 
@@ -763,7 +774,7 @@ public:
 	/*!
 	  \brief If this is an online capture, unset event_id.
 	  \param event type to unset
-	  \return SCAP_SUCCESS if the call is succesful
+	  \return SCAP_SUCCESS if the call is successful
 	   On Failure, SCAP_FAILURE is returned and getlasterr() can be used to
 	   obtain the cause of the error.
 
@@ -777,13 +788,29 @@ public:
 	*/
 	double get_read_progress();
 
+	/*!
+	  \brief Make the amount of data gathered for a syscall to be
+	  determined by the number of parameters.
+	*/
+	virtual int /*SCAP_X*/ dynamic_snaplen(bool enable)
+	{
+		if(enable)
+		{
+			return scap_enable_dynamic_snaplen(m_h);
+		}
+		else
+		{
+			return scap_disable_dynamic_snaplen(m_h);
+		}
+	}
+
 #ifndef CYGWING_AGENT
-	void init_k8s_ssl(const string *ssl_cert);
-	void init_k8s_client(string* api_server, string* ssl_cert, bool verbose = false);
+	void init_k8s_ssl(const std::string *ssl_cert);
+	void init_k8s_client(std::string* api_server, std::string* ssl_cert, bool verbose = false);
 	void make_k8s_client();
 	k8s* get_k8s_client() const { return m_k8s_client; }
 
-	void init_mesos_client(string* api_server, bool verbose = false);
+	void init_mesos_client(std::string* api_server, bool verbose = false);
 	mesos* get_mesos_client() const { return m_mesos_client; }
 #endif
 
@@ -817,7 +844,7 @@ public:
 
 	sinsp_parser* get_parser();
 
-	bool setup_cycle_writer(string base_file_name, int rollover_mb, int duration_seconds, int file_limit, unsigned long event_limit, bool compress);
+	bool setup_cycle_writer(std::string base_file_name, int rollover_mb, int duration_seconds, int file_limit, unsigned long event_limit, bool compress);
 	void import_ipv4_interface(const sinsp_ipv4_ifinfo& ifinfo);
 	void add_meta_event(sinsp_evt *metaevt);
 	void add_meta_event_callback(meta_event_callback cback, void* data);
@@ -834,8 +861,10 @@ public:
 		scap_refresh_proc_table(m_h);
 	}
 	void set_simpledriver_mode();
-	vector<long> get_n_tracepoint_hit();
-	void set_bpf_probe(const string& bpf_probe);
+	std::vector<long> get_n_tracepoint_hit();
+	void set_bpf_probe(const std::string& bpf_probe);
+
+	bool is_bpf_enabled();
 
 	static unsigned num_possible_cpus();
 #ifdef CYGWING_AGENT
@@ -867,6 +896,22 @@ public:
 
 	void set_query_docker_image_info(bool query_image_info);
 
+	void set_cri_extra_queries(bool extra_queries);
+
+	void set_fullcapture_port_range(uint16_t range_start, uint16_t range_end);
+
+	void set_statsd_port(uint16_t port);
+
+	void set_cri_socket_path(const std::string& path);
+	void set_cri_timeout(int64_t timeout_ms);
+
+VISIBILITY_PROTECTED
+	bool add_thread(const sinsp_threadinfo *ptinfo);
+	void set_mode(scap_mode_t value)
+	{
+		m_mode = value;
+	}
+
 VISIBILITY_PRIVATE
 
         static inline ppm_event_flags falco_skip_flags()
@@ -885,7 +930,6 @@ private:
 	void import_user_list();
 	void add_protodecoders();
 
-	void add_thread(const sinsp_threadinfo* ptinfo);
 	void remove_thread(int64_t tid, bool force);
 
 	//
@@ -963,18 +1007,24 @@ private:
 
 	void add_suppressed_comms(scap_open_args &oargs);
 
+	bool increased_snaplen_port_range_set() const
+	{
+		return m_increased_snaplen_port_range.range_start > 0 &&
+		       m_increased_snaplen_port_range.range_end > 0;
+	}
+
 	scap_t* m_h;
 	uint32_t m_nevts;
 	int64_t m_filesize;
 
-	scap_mode_t m_mode;
+	scap_mode_t m_mode = SCAP_MODE_NONE;
 
 	// If non-zero, reading from this fd and m_input_filename contains "fd
 	// <m_input_fd>". Otherwise, reading from m_input_filename.
 	int m_input_fd;
-	string m_input_filename;
+	std::string m_input_filename;
 	bool m_bpf;
-	string m_bpf_probe;
+	std::string m_bpf_probe;
 	bool m_isdebug_enabled;
 	bool m_isfatfile_enabled;
 	bool m_isinternal_events_enabled;
@@ -983,10 +1033,10 @@ private:
 	uint32_t m_max_evt_output_len;
 	bool m_compress;
 	sinsp_evt m_evt;
-	string m_lasterr;
+	std::string m_lasterr;
 	int64_t m_tid_to_remove;
 	int64_t m_tid_of_fd_to_remove;
-	vector<int64_t>* m_fds_to_remove;
+	std::vector<int64_t>* m_fds_to_remove;
 	uint64_t m_lastevent_ts;
 	// the parsing engine
 	sinsp_parser* m_parser;
@@ -1002,6 +1052,7 @@ private:
 	// restart in the middle of the file.
 	uint64_t m_file_start_offset;
 	bool m_flush_memory_dump;
+	bool m_large_envs_enabled;
 
 	sinsp_network_interfaces* m_network_interfaces;
 public:
@@ -1013,8 +1064,8 @@ public:
 	// Kubernetes
 	//
 #ifndef CYGWING_AGENT
-	string* m_k8s_api_server;
-	string* m_k8s_api_cert;
+	std::string* m_k8s_api_server;
+	std::string* m_k8s_api_cert;
 #ifdef HAS_CAPTURE
 	std::shared_ptr<sinsp_ssl> m_k8s_ssl;
 	std::shared_ptr<sinsp_bearer_token> m_k8s_bt;
@@ -1032,8 +1083,8 @@ public:
 	//
 	// Mesos/Marathon
 	//
-	string m_mesos_api_server;
-	vector<string> m_marathon_api_server;
+	std::string m_mesos_api_server;
+	std::vector<std::string> m_marathon_api_server;
 	mesos* m_mesos_client;
 	uint64_t m_mesos_last_watch_time_ns;
 
@@ -1045,7 +1096,7 @@ public:
 
 	//
 	// True if the command line argument is set to show container information
-	// The deafult is false set within the constructor
+	// The default is false set within the constructor
 	//
 	bool m_print_container_data;
 
@@ -1053,7 +1104,7 @@ public:
 	uint64_t m_firstevent_ts;
 	sinsp_filter* m_filter;
 	sinsp_evttype_filter *m_evttype_filter;
-	string m_filterstring;
+	std::string m_filterstring;
 
 #endif
 
@@ -1068,7 +1119,7 @@ public:
 	int32_t m_max_n_proc_lookups = -1;
 	int32_t m_max_n_proc_socket_lookups = -1;
 #ifdef HAS_ANALYZER
-	vector<uint64_t> m_tid_collisions;
+	std::vector<uint64_t> m_tid_collisions;
 #endif
 
 	//
@@ -1076,6 +1127,17 @@ public:
 	//
 	uint32_t m_snaplen;
 
+	//
+	// Saved increased capture range
+	//
+	struct
+	{
+		uint16_t range_start;
+		uint16_t range_end;
+	} m_increased_snaplen_port_range;
+
+	int32_t m_statsd_port;
+
 	//
 	// Some thread table limits
 	//
@@ -1124,17 +1186,7 @@ public:
 	//
 	// Protocol decoding state
 	//
-	vector<sinsp_protodecoder*> m_decoders_reset_list;
-
-	//
-	// Containers meta event management
-	//
-	sinsp_evt m_meta_evt; // XXX this should go away
-	char* m_meta_evt_buf; // XXX this should go away
-	bool m_meta_evt_pending; // XXX this should go away
-
-	int32_t m_meta_skipped_evt_res;
-	sinsp_evt* m_meta_skipped_evt;
+	std::vector<sinsp_protodecoder*> m_decoders_reset_list;
 
 	//
 	// meta event management for other sources like k8s, mesos.
@@ -1143,6 +1195,14 @@ public:
 	meta_event_callback m_meta_event_callback;
 	void* m_meta_event_callback_data;
 
+	// A queue of pending container events. Written from async
+	// callbacks that occur after looking up container
+	// information, read from sinsp::next().
+	tbb::concurrent_queue<shared_ptr<sinsp_evt>> m_pending_container_evts;
+
+	// Holds an event dequeued from the above queue
+	std::shared_ptr<sinsp_evt> m_container_evt;
+
 	//
 	// End of second housekeeping
 	//
@@ -1187,8 +1247,21 @@ public:
 	friend class sinsp_baseliner;
 	friend class sinsp_memory_dumper;
 	friend class sinsp_network_interfaces;
+	friend class test_helper;
 
 	template<class TKey,class THash,class TCompare> friend class sinsp_connection_manager;
+
+#ifdef SYSDIG_TEST
+protected:
+	void inject_machine_info(const scap_machine_info *value)
+	{
+		m_machine_info = value;
+	}
+	void inject_network_interfaces(sinsp_network_interfaces *value)
+	{
+		m_network_interfaces = value;
+	}
+#endif // SYSDIG_TEST
 };
 
 /*@}*/
