@@ -90,6 +90,7 @@ void sinsp_threadinfo::init()
 	m_lastevent_data = NULL;
 	m_parent_loop_detected = false;
 	m_tty = 0;
+	m_category = CAT_NONE;
 	m_blprogram = NULL;
 	m_loginuid = 0;
 }
@@ -324,6 +325,7 @@ void sinsp_threadinfo::add_fd_from_scap(scap_fdinfo *fdi, OUT sinsp_fdinfo_t *re
 	case SCAP_FD_FILE_V2:
 		newfdi->m_openflags = fdi->info.regularinfo.open_flags;
 		newfdi->m_name = fdi->info.regularinfo.fname;
+		newfdi->m_dev = fdi->info.regularinfo.dev;
 
 		if(newfdi->m_name == USER_EVT_DEVICE_NAME)
 		{
@@ -423,6 +425,7 @@ void sinsp_threadinfo::init(scap_threadinfo* pi)
 	m_clone_ts = pi->clone_ts;
 	m_tty = pi->tty;
 	m_loginuid = pi->loginuid;
+	m_category = CAT_NONE;
 
 	set_cgroups(pi->cgroups, pi->cgroups_len);
 	m_root = pi->root;
@@ -519,7 +522,7 @@ void sinsp_threadinfo::set_args(const char* args, size_t len)
 
 void sinsp_threadinfo::set_env(const char* env, size_t len)
 {
-	if (len == SCAP_MAX_ENV_SIZE && m_inspector->is_live())
+	if (len == SCAP_MAX_ENV_SIZE && m_inspector->large_envs_enabled())
 	{
 		// the environment is possibly truncated, try to read from /proc
 		// this may fail for short-lived processes
@@ -901,7 +904,8 @@ void sinsp_threadinfo::traverse_parent_state(visitor_func_t &visitor)
 	// Move fast to its parent
 	fast = (fast ? fast->get_parent_thread() : fast);
 
-	while(slow)
+	// The slow pointer must be valid and not have a tid of -1.
+	while(slow && slow->m_tid != -1)
 	{
 		if(!visitor(slow))
 		{
@@ -916,15 +920,20 @@ void sinsp_threadinfo::traverse_parent_state(visitor_func_t &visitor)
 		for (uint32_t i = 0; i < 2; i++) {
 			fast = (fast ? fast->get_parent_thread() : fast);
 
-			// If not at the end but fast == slow, there's a loop
-			// in the thread state.
-			if(slow && (slow == fast))
+			// If not at the end but fast == slow or if
+			// slow points to itself, there's a loop in
+			// the thread state.
+			if(slow && (slow == fast ||
+				    slow->m_tid == slow->m_ptid))
 			{
 				// Note we only log a loop once for a given main thread, to avoid flooding logs.
 				if(!m_parent_loop_detected)
 				{
 					g_logger.log(string("Loop in parent thread state detected for pid ") +
-						     std::to_string(m_pid), sinsp_logger::SEV_WARNING);
+						     std::to_string(m_pid) +
+						     ". stopped at tid= " + std::to_string(slow->m_tid) +
+						     " ptid=" + std::to_string(slow->m_ptid),
+						     sinsp_logger::SEV_WARNING);
 					m_parent_loop_detected = true;
 				}
 				return;
@@ -933,6 +942,26 @@ void sinsp_threadinfo::traverse_parent_state(visitor_func_t &visitor)
 	}
 }
 
+void sinsp_threadinfo::populate_cmdline(string &cmdline, sinsp_threadinfo *tinfo)
+{
+	cmdline = tinfo->get_comm();
+
+	uint32_t j;
+	uint32_t nargs = (uint32_t)tinfo->m_args.size();
+
+	for(j = 0; j < nargs; j++)
+	{
+		cmdline += " " + tinfo->m_args[j];
+	}
+}
+
+bool sinsp_threadinfo::is_health_probe()
+{
+	return (m_category == sinsp_threadinfo::CAT_HEALTHCHECK ||
+		m_category == sinsp_threadinfo::CAT_LIVENESS_PROBE ||
+		m_category == sinsp_threadinfo::CAT_READINESS_PROBE);
+}
+
 shared_ptr<sinsp_threadinfo> sinsp_threadinfo::lookup_thread()
 {
 	return m_inspector->get_thread_ref(m_pid, true, true);
@@ -1151,6 +1180,7 @@ void sinsp_threadinfo::fd_to_scap(scap_fdinfo *dst, sinsp_fdinfo_t* src)
 	case SCAP_FD_FILE_V2:
 		dst->info.regularinfo.open_flags = src->m_openflags;
 		strncpy(dst->info.regularinfo.fname, src->m_name.c_str(), SCAP_MAX_PATH_SIZE);
+		dst->info.regularinfo.dev = src->m_dev;
 		break;
 	case SCAP_FD_FIFO:
 	case SCAP_FD_FILE:
@@ -1224,7 +1254,7 @@ void sinsp_thread_manager::increment_mainthread_childcount(sinsp_threadinfo* thr
 	}
 }
 
-void sinsp_thread_manager::add_thread(sinsp_threadinfo* threadinfo, bool from_scap_proctable)
+bool sinsp_thread_manager::add_thread(sinsp_threadinfo *threadinfo, bool from_scap_proctable)
 {
 #ifdef GATHER_INTERNAL_STATS
 	m_added_threads->increment();
@@ -1238,8 +1268,14 @@ void sinsp_thread_manager::add_thread(sinsp_threadinfo* threadinfo, bool from_sc
 #endif
 		)
 	{
+		// rate limit messages to avoid spamming the logs
+		if (m_n_drops % m_inspector->m_max_thread_table_size == 0)
+		{
+			g_logger.format(sinsp_logger::SEV_INFO, "Thread table full, dropping tid %lu (pid %lu, comm \"%s\")",
+				threadinfo->m_tid, threadinfo->m_pid, threadinfo->m_comm.c_str());
+		}
 		m_n_drops++;
-		return;
+		return false;
 	}
 
 	if(!from_scap_proctable)
@@ -1255,6 +1291,7 @@ void sinsp_thread_manager::add_thread(sinsp_threadinfo* threadinfo, bool from_sc
 	{
 		m_listener->on_thread_created(threadinfo);
 	}
+	return true;
 }
 
 void sinsp_thread_manager::remove_thread(int64_t tid, bool force)
