@@ -1,24 +1,27 @@
 /*
-Copyright (C) 2013-2014 Draios inc.
+Copyright (C) 2013-2018 Draios Inc dba Sysdig.
 
 This file is part of sysdig.
 
-sysdig is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License version 2 as
-published by the Free Software Foundation.
+Licensed under the Apache License, Version 2.0 (the "License");
+you may not use this file except in compliance with the License.
+You may obtain a copy of the License at
 
-sysdig is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
+    http://www.apache.org/licenses/LICENSE-2.0
+
+Unless required by applicable law or agreed to in writing, software
+distributed under the License is distributed on an "AS IS" BASIS,
+WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+See the License for the specific language governing permissions and
+limitations under the License.
 
-You should have received a copy of the GNU General Public License
-along with sysdig.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 #pragma once
 
-/** @defgroup state State management 
+#include <stdint.h>
+
+/** @defgroup state State management
  *  @{
  */
 
@@ -47,15 +50,28 @@ typedef struct ipv4net
 	uint32_t m_netmask; ///< Subnet mask
 }ipv4net;
 
+typedef struct _ipv6addr
+{
+	uint32_t m_b[4];
+
+	bool operator==(const _ipv6addr &other) const;
+	bool operator!=(const _ipv6addr &other) const;
+	bool operator<(const _ipv6addr &other) const;
+	bool in_subnet(const _ipv6addr &other) const;
+
+	static struct _ipv6addr empty_address;
+}ipv6addr;
+
+
 /*!
 	\brief An IPv6 tuple. 
 */
 typedef union _ipv6tuple
 {
-	struct
-	{
-		uint32_t m_sip[4]; ///< source (i.e. client) address.
-		uint32_t m_dip[4]; ///< destination (i.e. server) address.
+	struct {
+
+		ipv6addr m_sip; ///< source (i.e. client) address.
+		ipv6addr m_dip; ///< destination (i.e. server) address.
 		uint16_t m_sport; ///< source (i.e. client) port.
 		uint16_t m_dport; ///< destination (i.e. server) port.
 		uint8_t m_l4proto; ///< Layer 4 protocol (e.g. TCP, UDP...)
@@ -78,7 +94,7 @@ typedef struct ipv4serverinfo
 */
 typedef struct ipv6serverinfo
 {
-	uint32_t m_ip[4];  ///< address
+	ipv6addr m_ip;  ///< address
 	uint16_t m_port;  ///< port
 	uint8_t m_l4proto;  ///< IP protocol
 } ipv6serverinfo;
