@@ -31,6 +31,7 @@ limitations under the License.
 #include <strings.h>
 #include <sys/ioctl.h>
 #include <fnmatch.h>
+#include <string>
 #else
 #pragma comment(lib, "Ws2_32.lib")
 #include <WinSock2.h>
@@ -71,19 +72,29 @@ const chiseldir_info g_chisel_dirs_array[] =
 #endif
 
 #ifndef _WIN32
-char* realpath_ex(const char *path, char *buff)
+static std::string realpath_ex(const std::string& path)
 {
 	char *home;
+	char* resolved;
 
-	if(*path=='~' && (home = getenv("HOME")))
+	if(!path.empty() && path[0]=='~' && (home = getenv("HOME")))
 	{
-		char s[PATH_MAX];
-		return realpath(strcat(strcpy(s, home), path+1), buff);
-		}
+		std::string expanded_home = home;
+		expanded_home += path.c_str()+1;
+		resolved = realpath(expanded_home.c_str(), nullptr);
+	}
 	else
 	{
-		return realpath(path, buff);
+		resolved = realpath(path.c_str(), nullptr);
 	}
+
+	if (!resolved)
+	{
+		return "";
+	}
+	std::string ret = resolved;
+	free(resolved);
+	return resolved;
 }
 #endif
 
@@ -133,20 +144,17 @@ sinsp_initializer::sinsp_initializer()
 		if(g_chisel_dirs_array[j].m_need_to_resolve)
 		{
 #ifndef _WIN32
-			char resolved_path[PATH_MAX];
-
-			if(realpath_ex(g_chisel_dirs_array[j].m_dir, resolved_path) != NULL)
+			std::string resolved_path = realpath_ex(g_chisel_dirs_array[j].m_dir);
+			if(!resolved_path.empty())
 			{
-				string resolved_path_str(resolved_path);
-
-				if(resolved_path_str[resolved_path_str.size() -1] != '/')
+				if(resolved_path[resolved_path.size() - 1] != '/')
 				{
-					resolved_path_str += "/";
+					resolved_path += '/';
 				}
 
 				chiseldir_info cdi;
 				cdi.m_need_to_resolve = false;
-				sprintf(cdi.m_dir, "%s", resolved_path_str.c_str());
+				cdi.m_dir = std::move(resolved_path);
 				g_chisel_dirs->push_back(cdi);
 			}
 #else
@@ -906,10 +914,109 @@ const char* sinsp_utils::event_name_by_id(uint16_t id)
 	return g_infotables.m_event_info[id].name;
 }
 
+void sinsp_utils::ts_to_string(uint64_t ts, OUT string* res, bool date, bool ns)
+{
+	struct tm *tm;
+	time_t Time;
+	uint64_t sec = ts / ONE_SECOND_IN_NS;
+	uint64_t nsec = ts % ONE_SECOND_IN_NS;
+	int32_t thiszone = gmt2local(0);
+	int32_t s = (sec + thiszone) % 86400;
+	int32_t bufsize = 0;
+	char buf[256];
+
+	if(date)
+	{
+		Time = (sec + thiszone) - s;
+		tm = gmtime (&Time);
+		if(!tm)
+		{
+			bufsize = sprintf(buf, "<date error> ");
+		}
+		else
+		{
+			bufsize = sprintf(buf, "%04d-%02d-%02d ",
+				   tm->tm_year+1900, tm->tm_mon+1, tm->tm_mday);
+		}
+	}
+
+	if(ns)
+	{
+		sprintf(buf + bufsize, "%02d:%02d:%02d.%09u",
+				s / 3600, (s % 3600) / 60, s % 60, (unsigned)nsec);
+	}
+	else
+	{
+		sprintf(buf + bufsize, "%02d:%02d:%02d",
+				s / 3600, (s % 3600) / 60, s % 60);
+	}
+
+	*res = buf;
+}
+
+void sinsp_utils::ts_to_iso_8601(uint64_t ts, OUT string* res)
+{
+	static const char *fmt = "YYYY-MM-DDTHH:MM:SS-0000";
+	static const uint32_t fmtlen = strlen(fmt);
+	char buf[fmtlen];
+	uint64_t ns = ts % ONE_SECOND_IN_NS;
+	time_t sec = ts / ONE_SECOND_IN_NS;
+
+	if(strftime(buf, sizeof(buf), "%FT%T", gmtime(&sec)) == 0)
+	{
+		*res = fmt;
+		return;
+	}
+
+	*res = buf;
+	if(sprintf(buf, ".%09u", (unsigned) ns) < 0)
+	{
+		*res = fmt;
+		return;
+	}
+	*res += buf;
+	if(strftime(buf, sizeof(buf), "%z", gmtime(&sec)) == 0)
+	{
+		*res = fmt;
+		return;
+	}
+	*res += buf;
+}
+
 ///////////////////////////////////////////////////////////////////////////////
 // Time utility functions.
 ///////////////////////////////////////////////////////////////////////////////
 
+bool sinsp_utils::parse_iso_8601_utc_string(const std::string& time_str, uint64_t &ns)
+{
+#ifndef _WIN32
+	char *rem;
+
+	struct tm tm_time = {0};
+	rem = strptime(time_str.c_str(), "%Y-%m-%dT%H:%M:", &tm_time);
+	if(rem == NULL || *rem == '\0')
+	{
+		return false;
+	}
+	tm_time.tm_isdst = -1; // strptime does not set this, signal timegm to determine DST
+	ns = timegm(&tm_time) * ONE_SECOND_IN_NS;
+
+	// Handle the possibly fractional seconds now. Also verify
+	// that the string ends with Z.
+	double fractional_secs;
+	if(sscanf(rem, "%lfZ", &fractional_secs) != 1)
+	{
+		return false;
+	}
+
+	ns += (fractional_secs * ONE_SECOND_IN_NS);
+
+	return true;
+#else
+	throw sinsp_exception("parse_iso_8601_utc_string() not implemented on Windows");
+#endif
+}
+
 time_t get_epoch_utc_seconds(const std::string& time_str, const std::string& fmt)
 {
 #ifndef _WIN32
@@ -1183,6 +1290,8 @@ const char* param_type_to_string(ppm_param_type pt)
 		return "FLAGS16";
 	case PT_FLAGS32:
 		return "FLAGS32";
+	case PT_MODE:
+		return "MODE";
 	case PT_UID:
 		return "UID";
 	case PT_GID:
