@@ -78,6 +78,13 @@ static void usage()
 "                    The BPF probe can also be specified via the environment variable\n"
 "                    SYSDIG_BPF_PROBE. If <bpf_probe> is left empty, sysdig will\n"
 "                    try to load one from the sysdig-probe-loader script.\n"
+#ifdef HAS_CAPTURE
+" --cri <path>       Path to CRI socket for container metadata\n"
+"                    Use the specified socket to fetch data from a CRI-compatible runtime\n"
+"\n"
+" --cri-timeout <timeout_ms>\n"
+"                    Wait at most <timeout_ms> milliseconds for response from CRI\n"
+#endif
 " -d <period>, --delay=<period>\n"
 "                    Set the delay between updates, in milliseconds. This works\n"
 "                    similarly to the -d option in top.\n"
@@ -112,6 +119,12 @@ static void usage()
 "                    ':' or '#' characters in the file name.\n"
 "                    Option can also be provided via the environment variable SYSDIG_K8S_API_CERT.\n"
 " -l, --list         List all the fields that can be used in views.\n"
+" --large-environment\n"
+"                    Support environments larger than 4KiB\n"
+"                    When the environment is larger than 4KiB, load the whole\n"
+"                    environment from /proc instead of truncating to the first 4KiB\n"
+"                    This may fail for short-lived processes and in that case\n"
+"                    the truncated environment is used instead.\n"
 " --logfile=<file>\n"
 "                    Print program logs into the given file.\n"
 " -n <num>, --numevents=<num>\n"
@@ -307,6 +320,9 @@ sysdig_init_res csysdig_init(int argc, char **argv)
 	bool list_views = false;
 	bool bpf = false;
 	string bpf_probe;
+#ifdef HAS_CAPTURE
+	string cri_socket_path;
+#endif
 
 #ifndef _WIN32
 	sinsp_table::output_type output_type = sinsp_table::OT_CURSES;
@@ -326,6 +342,10 @@ sysdig_init_res csysdig_init(int argc, char **argv)
 	{
 		{"print-ascii", no_argument, 0, 'A' },
 		{"bpf", optional_argument, 0, 'B' },
+#ifdef HAS_CAPTURE
+		{"cri", required_argument, 0, 0 },
+		{"cri-timeout", required_argument, 0, 0 },
+#endif
 		{"delay", required_argument, 0, 'd' },
 		{"exclude-users", no_argument, 0, 'E' },
 		{"from", required_argument, 0, 0 },
@@ -334,6 +354,7 @@ sysdig_init_res csysdig_init(int argc, char **argv)
 		{"k8s-api-cert", required_argument, 0, 'K' },
 		{"json", no_argument, 0, 'j' },
 		{"interactive", optional_argument, 0, 0 },
+		{"large-environment", no_argument, 0, 0 },
 		{"list", optional_argument, 0, 'l' },
 		{"list-views", no_argument, 0, 0},
 		{"mesos-api", required_argument, 0, 'm'},
@@ -508,6 +529,20 @@ sysdig_init_res csysdig_init(int argc, char **argv)
 						is_interactive = true;
 						output_type = sinsp_table::OT_JSON;
 					}
+					else if(optname == "large-environment")
+					{
+						inspector->set_large_envs(true);
+					}
+#ifdef HAS_CAPTURE
+					else if(optname == "cri")
+					{
+						cri_socket_path = optarg;
+					}
+					else if(optname == "cri-timeout")
+					{
+						inspector->set_cri_timeout(sinsp_numparser::parsed64(optarg));
+					}
+#endif
 					else if(optname == "logfile")
 					{
 						inspector->set_log_file(optarg);
@@ -547,6 +582,13 @@ sysdig_init_res csysdig_init(int argc, char **argv)
 			}
 		}
 
+#ifdef HAS_CAPTURE
+		if(!cri_socket_path.empty())
+		{
+			inspector->set_cri_socket_path(cri_socket_path);
+		}
+#endif
+
 		string filter;
 
 		//
