@@ -92,6 +92,13 @@ static void usage()
 "                    starting at 0 and continuing upward. The units of file_size\n"
 "                    are millions of bytes (10^6, not 2^20). Use the -W flag to\n"
 "                    determine how many files will be saved to disk.\n"
+#ifdef HAS_CAPTURE
+" --cri <path>       Path to CRI socket for container metadata\n"
+"                    Use the specified socket to fetch data from a CRI-compatible runtime\n"
+"\n"
+" --cri-timeout <timeout_ms>\n"
+"                    Wait at most <timeout_ms> milliseconds for response from CRI\n"
+#endif
 " -d, --displayflt   Make the given filter a display one\n"
 "                    Setting this option causes the events to be filtered\n"
 "                    after being parsed by the state system. Events are\n"
@@ -166,6 +173,12 @@ static void usage()
 " -l, --list         List the fields that can be used for filtering and output\n"
 "                    formatting. Use -lv to get additional information for each\n"
 "                    field.\n"
+" --large-environment\n"
+"                    Support environments larger than 4KiB\n"
+"                    When the environment is larger than 4KiB, load the whole\n"
+"                    environment from /proc instead of truncating to the first 4KiB\n"
+"                    This may fail for short-lived processes and in that case\n"
+"                    the truncated environment is used instead.\n"
 " --list-markdown    like -l, but produces markdown output\n"
 " -m <url[,marathon_url]>, --mesos-api=<url[,marathon_url]>\n"
 "                    Enable Mesos support by connecting to the API server\n"
@@ -755,7 +768,6 @@ sysdig_init_res sysdig_init(int argc, char **argv)
 	uint32_t snaplen = 0;
 	int long_index = 0;
 	int32_t n_filterargs = 0;
-	int cflag = 0;
 	bool jflag = false;
 	bool unbuf_flag = false;
 	bool filter_proclist_flag = false;
@@ -769,6 +781,9 @@ sysdig_init_res sysdig_init(int argc, char **argv)
 	bool bpf = false;
 	string bpf_probe;
 	std::set<std::string> suppress_comms;
+#ifdef HAS_CAPTURE
+	string cri_socket_path;
+#endif
 
 	// These variables are for the cycle_writer engine
 	int duration_seconds = 0;
@@ -783,7 +798,11 @@ sysdig_init_res sysdig_init(int argc, char **argv)
 		{"bpf", optional_argument, 0, 'B' },
 #ifdef HAS_CHISELS
 		{"chisel", required_argument, 0, 'c' },
-		{"list-chisels", no_argument, &cflag, 1 },
+		{"list-chisels", no_argument, 0, 0 },
+#endif
+#ifdef HAS_CAPTURE
+		{"cri", required_argument, 0, 0 },
+		{"cri-timeout", required_argument, 0, 0 },
 #endif
 		{"displayflt", no_argument, 0, 'd' },
 		{"debug", no_argument, 0, 'D'},
@@ -800,6 +819,7 @@ sysdig_init_res sysdig_init(int argc, char **argv)
 		{"json", no_argument, 0, 'j' },
 		{"k8s-api", required_argument, 0, 'k'},
 		{"k8s-api-cert", required_argument, 0, 'K' },
+		{"large-environment", no_argument, 0, 0 },
 		{"list", no_argument, 0, 'l' },
 		{"list-events", no_argument, 0, 'L' },
 		{"list-markdown", no_argument, 0, 0 },
@@ -881,33 +901,11 @@ sysdig_init_res sysdig_init(int argc, char **argv)
 				}
 				break;
 			}
-			case 0:
-				if(cflag != 1 && cflag != 2)
-				{
-					break;
-				}
-
-				if(cflag == 2)
-				{
-					cname = optarg;
-				}
 #ifdef HAS_CHISELS
 			case 'c':
 				{
-					if(cflag == 0)
-					{
-						string ostr(optarg);
-
-						if(ostr.size() >= 1)
-						{
-							if(ostr == "l")
-							{
-								cflag = 1;
-							}
-						}
-					}
-
-					if(cflag == 1)
+					string chisel = optarg;
+					if(chisel == "l")
 					{
 						vector<chisel_desc> chlist;
 						sinsp_chisel::get_chisel_list(&chlist);
@@ -916,7 +914,7 @@ sysdig_init_res sysdig_init(int argc, char **argv)
 						return sysdig_init_res(EXIT_SUCCESS);
 					}
 
-					sinsp_chisel* ch = new sinsp_chisel(inspector, optarg);
+					sinsp_chisel* ch = new sinsp_chisel(inspector, chisel);
 					parse_chisel_args(ch, inspector, optind, argc, argv, &n_filterargs);
 					g_chisels.push_back(ch);
 				}
@@ -1181,6 +1179,54 @@ sysdig_init_res sysdig_init(int argc, char **argv)
 			case 'z':
 				compress = true;
 				break;
+			case 0:
+				{
+					string optname = string(long_options[long_index].name);
+					if (long_options[long_index].flag != 0) {
+						break;
+					}
+					if (optname == "version") {
+						printf("sysdig version %s\n", SYSDIG_VERSION);
+						delete inspector;
+						return sysdig_init_res(EXIT_SUCCESS);
+					}
+					else if (optname == "list-chisels") {
+						vector<chisel_desc> chlist;
+						sinsp_chisel::get_chisel_list(&chlist);
+						list_chisels(&chlist, true);
+						delete inspector;
+						return sysdig_init_res(EXIT_SUCCESS);
+					}
+#ifdef HAS_CAPTURE
+					else if (optname == "cri") {
+						cri_socket_path = optarg;
+					}
+					else if (optname == "cri-timeout") {
+						inspector->set_cri_timeout(sinsp_numparser::parsed64(optarg));
+					}
+#endif
+					else if (optname == "unbuffered") {
+						unbuf_flag = true;
+					}
+
+					else if (optname == "filter-proclist") {
+						filter_proclist_flag = true;
+					}
+
+					else if (optname == "large-environment") {
+						inspector->set_large_envs(true);
+					}
+
+					else if (optname == "list-markdown") {
+						list_flds = true;
+						list_flds_markdown = true;
+					}
+
+					else if (optname == "page-faults") {
+						page_faults = true;
+					}
+				}
+				break;
             // getopt_long : '?' for an ambiguous match or an extraneous parameter
 			case '?':
 				delete inspector;
@@ -1189,36 +1235,15 @@ sysdig_init_res sysdig_init(int argc, char **argv)
 			default:
 				break;
 			}
-
-			if(string(long_options[long_index].name) == "version")
-			{
-				printf("sysdig version %s\n", SYSDIG_VERSION);
-				delete inspector;
-				return sysdig_init_res(EXIT_SUCCESS);
-			}
-
-			if(string(long_options[long_index].name) == "unbuffered")
-			{
-				unbuf_flag = true;
-			}
-
-			if(string(long_options[long_index].name) == "filter-proclist")
-			{
-				filter_proclist_flag = true;
-			}
-
-			if(string(long_options[long_index].name) == "list-markdown")
-			{
-				list_flds = true;
-				list_flds_markdown = true;
-			}
-
-			if(string(long_options[long_index].name) == "page-faults")
-			{
-				page_faults = true;
-			}
 		}
 
+#ifdef HAS_CAPTURE
+		if(!cri_socket_path.empty())
+		{
+			inspector->set_cri_socket_path(cri_socket_path);
+		}
+#endif
+
 		if(!bpf)
 		{
 			const char *probe = scap_get_bpf_probe_from_env();
